@@ -4,6 +4,7 @@
  * Copyright (C) 2004-2011 Laurent Destailleur  <eldy@users.sourceforge.net>
  * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
  * Copyright (C) 2013	   Florian Henry        <florian.henry@open-concept.pro>
+ * Copyright (C) 2015      Alexandre Spangaro   <aspangaro.dolibarr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +27,16 @@
  */
 
 require '../main.inc.php';
+require_once DOL_DOCUMENT_ROOT.'/core/lib/member.lib.php';
 require_once DOL_DOCUMENT_ROOT.'/adherents/class/adherent.class.php';
 require_once DOL_DOCUMENT_ROOT.'/adherents/class/adherent_type.class.php';
 require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
 
 $langs->load("members");
 
-$rowid		= GETPOST('rowid','int');
-$action		= GETPOST('action','alpha');
+$rowid  = GETPOST('rowid','int');
+$action = GETPOST('action','alpha');
+$cancel = GETPOST('cancel','alpha');
 
 $search_lastname	= GETPOST('search_lastname','alpha');
 $search_login		= GETPOST('search_login','alpha');
@@ -51,6 +54,12 @@ $pagenext = $page + 1;
 if (! $sortorder) {  $sortorder="DESC"; }
 if (! $sortfield) {  $sortfield="d.lastname"; }
 
+$label=GETPOST("libelle","alpha");
+$cotisation=GETPOST("cotisation","int");
+$vote=GETPOST("vote","int");
+$comment=GETPOST("comment");
+$mail_valid=GETPOST("mail_valid");
+
 // Security check
 $result=restrictedArea($user,'adherent',$rowid,'adherent_type');
 
@@ -59,7 +68,7 @@ $extrafields = new ExtraFields($db);
 // fetch optionals attributes and labels
 $extralabels=$extrafields->fetch_name_optionals_label('adherent_type');
 
-if (GETPOST('button_removefilter'))
+if (GETPOST("button_removefilter_x") || GETPOST("button_removefilter")) // Both test are required to be compatible with all browsers
 {
     $search_lastname="";
     $search_login="";
@@ -70,29 +79,30 @@ if (GETPOST('button_removefilter'))
 
 
 // Initialize technical object to manage hooks of thirdparties. Note that conf->hooks_modules contains array array
-$hookmanager->initHooks(array('membertypecard'));
+$hookmanager->initHooks(array('membertypecard','globalcard'));
 
 /*
  *	Actions
  */
 if ($action == 'add' && $user->rights->adherent->configurer)
 {
-	if ($_POST["button"] != $langs->trans("Cancel"))
+	if (! $cancel)
 	{
-		$adht = new AdherentType($db);
+		$object = new AdherentType($db);
 
-		$adht->libelle     = trim($_POST["libelle"]);
-		$adht->cotisation  = trim($_POST["cotisation"]);
-		$adht->note        = trim($_POST["comment"]);
-		$adht->mail_valid  = trim($_POST["mail_valid"]);
-		$adht->vote        = trim($_POST["vote"]);
+		$object->libelle     = trim($label);
+		$object->cotisation  = trim($cotisation);
+		$object->note        = trim($comment);
+		$object->mail_valid  = trim($mail_valid);
+		$object->vote        = trim($vote);
 
 		// Fill array 'array_options' with data from add form
-		$ret = $extrafields->setOptionalsFromPost($extralabels,$adht);
+		$ret = $extrafields->setOptionalsFromPost($extralabels,$object);
+		if ($ret < 0) $error++;
 
-		if ($adht->libelle)
+		if ($object->libelle)
 		{
-			$id=$adht->create($user->id);
+			$id=$object->create($user);
 			if ($id > 0)
 			{
 				header("Location: ".$_SERVER["PHP_SELF"]);
@@ -100,7 +110,7 @@ if ($action == 'add' && $user->rights->adherent->configurer)
 			}
 			else
 			{
-				$mesg=$adht->error;
+				$mesg=$object->error;
 				$action = 'create';
 			}
 		}
@@ -114,20 +124,21 @@ if ($action == 'add' && $user->rights->adherent->configurer)
 
 if ($action == 'update' && $user->rights->adherent->configurer)
 {
-	if ($_POST["button"] != $langs->trans("Cancel"))
+	if (! $cancel)
 	{
-		$adht = new AdherentType($db);
-		$adht->id          = $_POST["rowid"];
-		$adht->libelle     = trim($_POST["libelle"]);
-		$adht->cotisation  = trim($_POST["cotisation"]);
-		$adht->note        = trim($_POST["comment"]);
-		$adht->mail_valid  = trim($_POST["mail_valid"]);
-		$adht->vote        = trim($_POST["vote"]);
+		$object = new AdherentType($db);
+		$object->id          = $rowid;
+		$object->libelle     = trim($label);
+		$object->cotisation  = trim($cotisation);
+		$object->note        = trim($comment);
+		$object->mail_valid  = trim($mail_valid);
+		$object->vote        = trim($vote);
 
 		// Fill array 'array_options' with data from add form
-		$ret = $extrafields->setOptionalsFromPost($extralabels,$adht);
+		$ret = $extrafields->setOptionalsFromPost($extralabels,$object);
+		if ($ret < 0) $error++;
 
-		$adht->update($user->id);
+		$object->update($user);
 
 		header("Location: ".$_SERVER["PHP_SELF"]."?rowid=".$_POST["rowid"]);
 		exit;
@@ -136,19 +147,12 @@ if ($action == 'update' && $user->rights->adherent->configurer)
 
 if ($action == 'delete' && $user->rights->adherent->configurer)
 {
-	$adht = new AdherentType($db);
-	$adht->delete($rowid);
+	$object = new AdherentType($db);
+	$object->delete($rowid);
 	header("Location: ".$_SERVER["PHP_SELF"]);
 	exit;
 }
 
-if ($action == 'commentaire' && $user->rights->adherent->configurer)
-{
-	$don = new Don($db);
-	$don->fetch($rowid);
-	$don->update_note(dol_html_entity_decode(GETPOST('commentaire'), ENT_QUOTES));
-}
-
 
 /*
  * View
@@ -159,13 +163,13 @@ llxHeader('',$langs->trans("MembersTypeSetup"),'EN:Module_Foundations|FR:Module_
 $form=new Form($db);
 
 
-// Liste of members type
-
+// List of members type
 if (! $rowid && $action != 'create' && $action != 'edit')
 {
 
-	print_fiche_titre($langs->trans("MembersTypes"));
+	print load_fiche_titre($langs->trans("MembersTypes"));
 
+	//dol_fiche_head('');
 
 	$sql = "SELECT d.rowid, d.libelle, d.cotisation, d.vote";
 	$sql.= " FROM ".MAIN_DB_PREFIX."adherent_type as d";
@@ -194,10 +198,13 @@ if (! $rowid && $action != 'create' && $action != 'edit')
 			$var=!$var;
 			print "<tr ".$bc[$var].">";
 			print '<td><a href="'.$_SERVER["PHP_SELF"].'?rowid='.$objp->rowid.'">'.img_object($langs->trans("ShowType"),'group').' '.$objp->rowid.'</a></td>';
-			print '<td>'.$objp->libelle.'</td>';
+			print '<td>'.dol_escape_htmltag($objp->libelle).'</td>';
 			print '<td align="center">'.yn($objp->cotisation).'</td>';
 			print '<td align="center">'.yn($objp->vote).'</td>';
-			print '<td align="right"><a href="'.$_SERVER["PHP_SELF"].'?action=edit&rowid='.$objp->rowid.'">'.img_edit().'</a></td>';
+			if ($user->rights->adherent->configurer)
+				print '<td align="right"><a href="'.$_SERVER["PHP_SELF"].'?action=edit&rowid='.$objp->rowid.'">'.img_edit().'</a></td>';
+			else
+				print '<td align="right">&nbsp;</td>';
 			print "</tr>";
 			$i++;
 		}
@@ -207,45 +214,30 @@ if (! $rowid && $action != 'create' && $action != 'edit')
 	{
 		dol_print_error($db);
 	}
-
-
-	/*
-	 * Barre d'actions
-	 *
-	 */
-	print '<div class="tabsAction">';
-
-	// New type
-	if ($user->rights->adherent->configurer)
-	{
-		print '<div class="inline-block divButAction"><a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=create">'.$langs->trans("NewType").'</a></div>';
-	}
-
-	print "</div>";
-
 }
 
 
 /* ************************************************************************** */
 /*                                                                            */
-/* Creation d'un type adherent                                                */
+/* Creation mode                                                              */
 /*                                                                            */
 /* ************************************************************************** */
 if ($action == 'create')
 {
-	$adht = new AdherentType($db);
+	$object = new AdherentType($db);
 
-	print_fiche_titre($langs->trans("NewMemberType"));
-
-	if ($mesg) print '<div class="error">'.$mesg.'</div>';
+	print load_fiche_titre($langs->trans("NewMemberType"));
 
 	print '<form action="'.$_SERVER['PHP_SELF'].'" method="POST">';
 	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
-	print '<table class="border" width="100%">';
-
 	print '<input type="hidden" name="action" value="add">';
 
-	print '<tr><td class="fieldrequired">'.$langs->trans("Label").'</td><td><input type="text" name="libelle" size="40"></td></tr>';
+    dol_fiche_head('');
+
+	print '<table class="border" width="100%">';
+	print '<tbody>';
+
+	print '<tr><td class="titlefieldcreate fieldrequired">'.$langs->trans("Label").'</td><td><input type="text" name="libelle" size="40"></td></tr>';
 
 	print '<tr><td>'.$langs->trans("SubscriptionRequired").'</td><td>';
 	print $form->selectyesno("cotisation",1,1);
@@ -256,11 +248,11 @@ if ($action == 'create')
 	print '</td></tr>';
 
 	print '<tr><td valign="top">'.$langs->trans("Description").'</td><td>';
-	print '<textarea name="comment" wrap="soft" cols="60" rows="3"></textarea></td></tr>';
+	print '<textarea name="comment" wrap="soft" class="centpercent" rows="3"></textarea></td></tr>';
 
 	print '<tr><td valign="top">'.$langs->trans("WelcomeEMail").'</td><td>';
 	require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
-	$doleditor=new DolEditor('mail_valid',$adht->mail_valid,'',280,'dolibarr_notes','',false,true,$conf->fckeditor->enabled,15,90);
+	$doleditor=new DolEditor('mail_valid',$object->mail_valid,'',280,'dolibarr_notes','',false,true,$conf->fckeditor->enabled,15,90);
 	$doleditor->Create();
 	print '</td></tr>';
 
@@ -269,40 +261,39 @@ if ($action == 'create')
 	$reshook=$hookmanager->executeHooks('formObjectOptions',$parameters,$act,$action);    // Note that $action and $object may have been modified by hook
 	if (empty($reshook) && ! empty($extrafields->attribute_label))
 	{
-		print $adht->showOptionals($extrafields,'edit');
+		print $object->showOptionals($extrafields,'edit');
 	}
+	print '<tbody>';
 	print "</table>\n";
 
-	print '<br>';
-	print '<center><input type="submit" name="button" class="button" value="'.$langs->trans("Add").'"> &nbsp; &nbsp; ';
-	print '<input type="submit" name="button" class="button" value="'.$langs->trans("Cancel").'"></center>';
+	dol_fiche_end();
+
+	print '<div class="center">';
+	print '<input type="submit" name="button" class="button" value="'.$langs->trans("Add").'">';
+	print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+	print '<input type="submit" name="cancel" class="button" value="'.$langs->trans("Cancel").'" onclick="history.go(-1)" />';
+	print '</div>';
 
 	print "</form>\n";
 }
 
 /* ************************************************************************** */
 /*                                                                            */
-/* Edition de la fiche                                                        */
+/* View mode                                                                  */
 /*                                                                            */
 /* ************************************************************************** */
 if ($rowid > 0)
 {
 	if ($action != 'edit')
 	{
-		$adht = new AdherentType($db);
-		$adht->fetch($rowid);
-		$adht->fetch_optionals($rowid,$extralabels);
+		$object = new AdherentType($db);
+		$object->fetch($rowid);
+		$object->fetch_optionals($rowid,$extralabels);
 
-		$h=0;
-
-		$head[$h][0] = $_SERVER["PHP_SELF"].'?rowid='.$adht->id;
-		$head[$h][1] = $langs->trans("Card");
-		$head[$h][2] = 'card';
-		$h++;
+		$head = member_type_prepare_head($object);
 
 		dol_fiche_head($head, 'card', $langs->trans("MemberType"), 0, 'group');
 
-
 		print '<table class="border" width="100%">';
 
 		$linkback = '<a href="'.DOL_URL_ROOT.'/adherents/type.php">'.$langs->trans("BackToList").'</a>';
@@ -310,25 +301,25 @@ if ($rowid > 0)
 		// Ref
 		print '<tr><td width="15%">'.$langs->trans("Ref").'</td>';
 		print '<td>';
-		print $form->showrefnav($adht, 'rowid', $linkback);
+		print $form->showrefnav($object, 'rowid', $linkback);
 		print '</td></tr>';
 
 		// Label
-		print '<tr><td width="15%">'.$langs->trans("Label").'</td><td>'.$adht->libelle.'</td></tr>';
+		print '<tr><td width="15%">'.$langs->trans("Label").'</td><td>'.dol_escape_htmltag($object->libelle).'</td></tr>';
 
 		print '<tr><td>'.$langs->trans("SubscriptionRequired").'</td><td>';
-		print yn($adht->cotisation);
+		print yn($object->cotisation);
 		print '</tr>';
 
 		print '<tr><td>'.$langs->trans("VoteAllowed").'</td><td>';
-		print yn($adht->vote);
+		print yn($object->vote);
 		print '</tr>';
 
 		print '<tr><td valign="top">'.$langs->trans("Description").'</td><td>';
-		print nl2br($adht->note)."</td></tr>";
+		print nl2br($object->note)."</td></tr>";
 
 		print '<tr><td valign="top">'.$langs->trans("WelcomeEMail").'</td><td>';
-		print nl2br($adht->mail_valid)."</td></tr>";
+		print nl2br($object->mail_valid)."</td></tr>";
 
 		// Other attributes
 		$parameters=array();
@@ -336,37 +327,38 @@ if ($rowid > 0)
 		if (empty($reshook) && ! empty($extrafields->attribute_label))
 		{
 			// View extrafields
-			print $adht->showOptionals($extrafields);
+			print $object->showOptionals($extrafields);
 		}
 
 		print '</table>';
-		print '</div>';
+
+		dol_fiche_end();
+
 
 		/*
-		 * Barre d'actions
-		 *
+		 * Hotbar
 		 */
 		print '<div class="tabsAction">';
 
 		// Edit
 		if ($user->rights->adherent->configurer)
 		{
-			print '<div class="inline-block divButAction"><a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=edit&amp;rowid='.$adht->id.'">'.$langs->trans("Modify").'</a></div>';
+			print '<div class="inline-block divButAction"><a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=edit&amp;rowid='.$object->id.'">'.$langs->trans("Modify").'</a></div>';
 		}
 
 		// Add
-		print '<div class="inline-block divButAction"><a class="butAction" href="fiche.php?action=create&typeid='.$adht->id.'">'.$langs->trans("AddMember").'</a></div>';
+		print '<div class="inline-block divButAction"><a class="butAction" href="card.php?action=create&typeid='.$object->id.'">'.$langs->trans("AddMember").'</a></div>';
 
 		// Delete
 		if ($user->rights->adherent->configurer)
 		{
-			print '<div class="inline-block divButAction"><a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?action=delete&rowid='.$adht->id.'">'.$langs->trans("DeleteType").'</a></div>';
+			print '<div class="inline-block divButAction"><a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?action=delete&rowid='.$object->id.'">'.$langs->trans("DeleteType").'</a></div>';
 		}
 
 		print "</div>";
 
 
-		// Show list of members (nearly same code than in page liste.php)
+		// Show list of members (nearly same code than in page list.php)
 
 		$membertypestatic=new AdherentType($db);
 
@@ -379,12 +371,12 @@ if ($rowid > 0)
 		$sql.= " FROM ".MAIN_DB_PREFIX."adherent as d, ".MAIN_DB_PREFIX."adherent_type as t";
 		$sql.= " WHERE d.fk_adherent_type = t.rowid ";
 		$sql.= " AND d.entity IN (".getEntity().")";
-		$sql.= " AND t.rowid = ".$adht->id;
+		$sql.= " AND t.rowid = ".$object->id;
 		if ($sall)
 		{
 		    $sql.= " AND (d.firstname LIKE '%".$sall."%' OR d.lastname LIKE '%".$sall."%' OR d.societe LIKE '%".$sall."%'";
 		    $sql.= " OR d.email LIKE '%".$sall."%' OR d.login LIKE '%".$sall."%' OR d.address LIKE '%".$sall."%'";
-		    $sql.= " OR d.town LIKE '%".$sall."%' OR d.note LIKE '%".$sall."%')";
+		    $sql.= " OR d.town LIKE '%".$sall."%' OR d.note_public LIKE '%".$sall."%' OR d.note_private LIKE '%".$sall."%')";
 		}
 		if ($status != '')
 		{
@@ -411,11 +403,11 @@ if ($rowid > 0)
 		}
 		if ($filter == 'uptodate')
 		{
-		    $sql.=" AND datefin >= ".$db->idate($now);
+		    $sql.=" AND datefin >= '".$db->idate($now)."'";
 		}
 		if ($filter == 'outofdate')
 		{
-		    $sql.=" AND datefin < ".$db->idate($now);
+		    $sql.=" AND datefin < '".$db->idate($now)."'";
 		}
 		// Count total nb of records
 		$nbtotalofrecords = 0;
@@ -477,7 +469,7 @@ if ($rowid > 0)
 		    print '<tr class="liste_titre">';
 		    print_liste_field_titre($langs->trans("Name")." / ".$langs->trans("Company"),$_SERVER["PHP_SELF"],"d.lastname",$param,"","",$sortfield,$sortorder);
 		    print_liste_field_titre($langs->trans("Login"),$_SERVER["PHP_SELF"],"d.login",$param,"","",$sortfield,$sortorder);
-		    print_liste_field_titre($langs->trans("Person"),$_SERVER["PHP_SELF"],"d.morphy",$param,"","",$sortfield,$sortorder);
+		    print_liste_field_titre($langs->trans("Nature"),$_SERVER["PHP_SELF"],"d.morphy",$param,"","",$sortfield,$sortorder);
 		    print_liste_field_titre($langs->trans("EMail"),$_SERVER["PHP_SELF"],"d.email",$param,"","",$sortfield,$sortorder);
 		    print_liste_field_titre($langs->trans("Status"),$_SERVER["PHP_SELF"],"d.statut,d.datefin",$param,"","",$sortfield,$sortorder);
 		    print_liste_field_titre($langs->trans("EndSubscription"),$_SERVER["PHP_SELF"],"d.datefin",$param,"",'align="center"',$sortfield,$sortorder);
@@ -491,15 +483,15 @@ if ($rowid > 0)
 			print '<tr class="liste_titre">';
 
 			print '<td class="liste_titre" align="left">';
-			print '<input class="flat" type="text" name="search_lastname" value="'.$search_lastname.'" size="12"></td>';
+			print '<input class="flat" type="text" name="search_lastname" value="'.dol_escape_htmltag($search_lastname).'" size="12"></td>';
 
 			print '<td class="liste_titre" align="left">';
-			print '<input class="flat" type="text" name="search_login" value="'.$search_login.'" size="7"></td>';
+			print '<input class="flat" type="text" name="search_login" value="'.dol_escape_htmltag($search_login).'" size="7"></td>';
 
 			print '<td class="liste_titre">&nbsp;</td>';
 
 			print '<td class="liste_titre" align="left">';
-			print '<input class="flat" type="text" name="search_email" value="'.$search_email.'" size="12"></td>';
+			print '<input class="flat" type="text" name="search_email" value="'.dol_escape_htmltag($search_email).'" size="12"></td>';
 
 			print '<td class="liste_titre">&nbsp;</td>';
 
@@ -528,11 +520,11 @@ if ($rowid > 0)
 		        print '<tr '.$bc[$var].'>';
 		        if ($objp->societe != '')
 		        {
-		            print '<td><a href="fiche.php?rowid='.$objp->rowid.'">'.img_object($langs->trans("ShowMember"),"user").' '.$adh->getFullName($langs,0,-1,20).' / '.dol_trunc($objp->societe,12).'</a></td>'."\n";
+		            print '<td><a href="card.php?rowid='.$objp->rowid.'">'.img_object($langs->trans("ShowMember"),"user").' '.$adh->getFullName($langs,0,-1,20).' / '.dol_trunc($objp->societe,12).'</a></td>'."\n";
 		        }
 		        else
 		        {
-		            print '<td><a href="fiche.php?rowid='.$objp->rowid.'">'.img_object($langs->trans("ShowMember"),"user").' '.$adh->getFullName($langs,0,-1,32).'</a></td>'."\n";
+		            print '<td><a href="card.php?rowid='.$objp->rowid.'">'.img_object($langs->trans("ShowMember"),"user").' '.$adh->getFullName($langs,0,-1,32).'</a></td>'."\n";
 		        }
 
 		        // Login
@@ -561,7 +553,7 @@ if ($rowid > 0)
 		        if ($datefin)
 		        {
 			        print '<td align="center" class="nowrap">';
-		            if ($datefin < time() && $objp->statut > 0)
+		            if ($datefin < dol_now() && $objp->statut > 0)
 		            {
 		                print dol_print_date($datefin,'day')." ".img_warning($langs->trans("SubscriptionLate"));
 		            }
@@ -590,12 +582,12 @@ if ($rowid > 0)
 		        print '<td align="center">';
 				if ($user->rights->adherent->creer)
 				{
-					print '<a href="fiche.php?rowid='.$objp->rowid.'&action=edit&return=liste.php">'.img_edit().'</a>';
+					print '<a href="card.php?rowid='.$objp->rowid.'&action=edit&return=list.php">'.img_edit().'</a>';
 				}
 				print '&nbsp;';
 				if ($user->rights->adherent->supprimer)
 				{
-					print '<a href="fiche.php?rowid='.$objp->rowid.'&action=resign&return=liste.php">'.img_picto($langs->trans("Resiliate"),'disable.png').'</a>';
+					print '<a href="card.php?rowid='.$objp->rowid.'&action=resign&return=list.php">'.img_picto($langs->trans("Resiliate"),'disable.png').'</a>';
 		        }
 				print "</td>";
 
@@ -617,46 +609,48 @@ if ($rowid > 0)
 
 	}
 
+	/* ************************************************************************** */
+	/*                                                                            */
+	/* Edition mode                                                               */
+	/*                                                                            */
+	/* ************************************************************************** */
+
 	if ($action == 'edit')
 	{
-		$adht = new AdherentType($db);
-		$adht->id = $rowid;
-		$adht->fetch($rowid);
-		$adht->fetch_optionals($rowid,$extralabels);
+		$object = new AdherentType($db);
+		$object->id = $rowid;
+		$object->fetch($rowid);
+		$object->fetch_optionals($rowid,$extralabels);
 
-		$h=0;
-
-		$head[$h][0] = $_SERVER["PHP_SELF"].'?rowid='.$adht->id;
-		$head[$h][1] = $langs->trans("Card");
-		$head[$h][2] = 'card';
-		$h++;
-
-		dol_fiche_head($head, 'card', $langs->trans("MemberType"), 0, 'group');
+		$head = member_type_prepare_head($object);
 
 		print '<form method="post" action="'.$_SERVER["PHP_SELF"].'?rowid='.$rowid.'">';
 		print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
 		print '<input type="hidden" name="rowid" value="'.$rowid.'">';
 		print '<input type="hidden" name="action" value="update">';
+
+		dol_fiche_head($head, 'card', $langs->trans("MemberType"), 0, 'group');
+
 		print '<table class="border" width="100%">';
 
-		print '<tr><td width="15%">'.$langs->trans("Ref").'</td><td>'.$adht->id.'</td></tr>';
+		print '<tr><td width="15%">'.$langs->trans("Ref").'</td><td>'.$object->id.'</td></tr>';
 
-		print '<tr><td>'.$langs->trans("Label").'</td><td><input type="text" name="libelle" size="40" value="'.$adht->libelle.'"></td></tr>';
+		print '<tr><td>'.$langs->trans("Label").'</td><td><input type="text" name="libelle" size="40" value="'.dol_escape_htmltag($object->libelle).'"></td></tr>';
 
 		print '<tr><td>'.$langs->trans("SubscriptionRequired").'</td><td>';
-		print $form->selectyesno("cotisation",$adht->cotisation,1);
+		print $form->selectyesno("cotisation",$object->cotisation,1);
 		print '</td></tr>';
 
 		print '<tr><td>'.$langs->trans("VoteAllowed").'</td><td>';
-		print $form->selectyesno("vote",$adht->vote,1);
+		print $form->selectyesno("vote",$object->vote,1);
 		print '</td></tr>';
 
 		print '<tr><td valign="top">'.$langs->trans("Description").'</td><td>';
-		print '<textarea name="comment" wrap="soft" cols="90" rows="3">'.$adht->note.'</textarea></td></tr>';
+		print '<textarea name="comment" wrap="soft" class="centpercent" rows="3">'.$object->note.'</textarea></td></tr>';
 
 		print '<tr><td valign="top">'.$langs->trans("WelcomeEMail").'</td><td>';
 		require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
-		$doleditor=new DolEditor('mail_valid',$adht->mail_valid,'',280,'dolibarr_notes','',false,true,$conf->fckeditor->enabled,15,90);
+		$doleditor=new DolEditor('mail_valid',$object->mail_valid,'',280,'dolibarr_notes','',false,true,$conf->fckeditor->enabled,15,90);
 		$doleditor->Create();
 		print "</td></tr>";
 
@@ -666,13 +660,22 @@ if ($rowid > 0)
 
 		print '</table>';
 
-		//Extra field
+		// Extra field
 		if (empty($reshook) && ! empty($extrafields->attribute_label))
 		{
 			print '<br><br><table class="border" width="100%">';
 			foreach($extrafields->attribute_label as $key=>$label)
 			{
-				$value=(isset($_POST["options_".$key])?$_POST["options_".$key]:(isset($adht->array_options['options_'.$key])?$adht->array_options['options_'.$key]:''));
+				if (isset($_POST["options_" . $key])) {
+					if (is_array($_POST["options_" . $key])) {
+						// $_POST["options"] is an array but following code expects a comma separated string
+						$value = implode(",", $_POST["options_" . $key]);
+					} else {
+						$value = $_POST["options_" . $key];
+					}
+				} else {
+					$value = $adht->array_options["options_" . $key];
+				}
 				print '<tr><td width="30%">'.$label.'</td><td>';
 				print $extrafields->showInputField($key,$value);
 				print "</td></tr>\n";
@@ -680,14 +683,19 @@ if ($rowid > 0)
 			print '</table><br><br>';
 		}
 
-		print '<center><input type="submit" class="button" value="'.$langs->trans("Save").'"> &nbsp; &nbsp;';
-		print '<input type="submit" name="button" class="button" value="'.$langs->trans("Cancel").'"></center>';
+		dol_fiche_end();
+
+		print '<div class="center">';
+		print '<input type="submit" class="button" value="'.$langs->trans("Save").'">';
+		print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+		print '<input type="submit" name="button" class="button" value="'.$langs->trans("Cancel").'">';
+		print '</div>';
 
 		print "</form>";
 	}
 }
 
-$db->close();
 
 llxFooter();
-?>
+
+$db->close();
