@@ -2,7 +2,7 @@
 /* Copyright (C) 2004		Rodolphe Quiedeville <rodolphe@quiedeville.org>
  * Copyright (C) 2004		Benoit Mortier       <benoit.mortier@opensides.be>
  * Copyright (C) 2005-2011	Regis Houssin        <regis.houssin@capnetworks.com>
- * Copyright (C) 2006-2011	Laurent Destailleur  <eldy@users.sourceforge.net>
+ * Copyright (C) 2006-2015	Laurent Destailleur  <eldy@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,11 +25,12 @@
  */
 
 /**
- *      \class      Ldap
- *      \brief      Class to manage LDAP features
+ *	Class to manage LDAP features
  */
 class Ldap
 {
+	var $error;
+
 	/**
 	 * Tableau des serveurs (IP addresses ou nom d'hotes)
 	 */
@@ -78,7 +79,7 @@ class Ldap
 	var $name;
 	var $firstname;
 	var $login;
-  var $phone;
+	var $phone;
 	var $skype;
 	var $fax;
 	var $mail;
@@ -107,7 +108,7 @@ class Ldap
 	{
 		global $conf;
 
-		//Server
+		// Server
 		if (! empty($conf->global->LDAP_SERVER_HOST))       $this->server[] = $conf->global->LDAP_SERVER_HOST;
 		if (! empty($conf->global->LDAP_SERVER_HOST_SLAVE)) $this->server[] = $conf->global->LDAP_SERVER_HOST_SLAVE;
 		$this->serverPort          = $conf->global->LDAP_SERVER_PORT;
@@ -119,16 +120,18 @@ class Ldap
 		$this->searchPassword      = $conf->global->LDAP_ADMIN_PASS;
 		$this->people              = $conf->global->LDAP_USER_DN;
 		$this->groups              = $conf->global->LDAP_GROUP_DN;
-		$this->filter              = $conf->global->LDAP_FILTER_CONNECTION;
 
-		//Users
+		$this->filter              = $conf->global->LDAP_FILTER_CONNECTION;	// Filter on user
+		$this->filtermember        = $conf->global->LDAP_MEMBER_FILTER;		// Filter on member
+		
+		// Users
 		$this->attr_login      = $conf->global->LDAP_FIELD_LOGIN; //unix
 		$this->attr_sambalogin = $conf->global->LDAP_FIELD_LOGIN_SAMBA; //samba, activedirectory
 		$this->attr_name       = $conf->global->LDAP_FIELD_NAME;
 		$this->attr_firstname  = $conf->global->LDAP_FIELD_FIRSTNAME;
 		$this->attr_mail       = $conf->global->LDAP_FIELD_MAIL;
 		$this->attr_phone      = $conf->global->LDAP_FIELD_PHONE;
-    $this->attr_skype      = $conf->global->LDAP_FIELD_SKYPE;
+		$this->attr_skype      = $conf->global->LDAP_FIELD_SKYPE;
 		$this->attr_fax        = $conf->global->LDAP_FIELD_FAX;
 		$this->attr_mobile     = $conf->global->LDAP_FIELD_MOBILE;
 	}
@@ -146,50 +149,65 @@ class Ldap
 	 */
 	function connect_bind()
 	{
-		global $langs;
+		global $langs, $conf;
 
 		$connected=0;
 		$this->bind=0;
 
-		foreach ($this->server as $key => $host)
+		// Check parameters
+		if (count($this->server) == 0 || empty($this->server[0]))
 		{
-			if ($connected) break;
+			$this->error='LDAP setup (file conf.php) is not complete';
+			dol_syslog(get_class($this)."::connect_bind ".$this->error, LOG_WARNING);
+			return -1;
+		}
 
-			if (preg_match('/^ldap/',$host))
-			{
-				$this->connection = ldap_connect($host);
-			}
-			else
-			{
-				$this->connection = ldap_connect($host,$this->serverPort);
-			}
+		if (! function_exists("ldap_connect"))
+		{
+			$this->error='LDAPFunctionsNotAvailableOnPHP';
+			dol_syslog(get_class($this)."::connect_bind ".$this->error, LOG_WARNING);
+			$return=-1;
+		}
 
-			if (is_resource($this->connection))
+		if (empty($this->error))
+		{
+			// Loop on each ldap server
+			foreach ($this->server as $key => $host)
 			{
-				$this->setVersion();
-
-				if ($this->serverType == "activedirectory")
+				if ($connected) break;
+				if (empty($host)) continue;
+	
+				if (preg_match('/^ldap/',$host))
 				{
-					$result=$this->setReferrals();
-					dol_syslog(get_class($this)."::connect_bind try bindauth for activedirectory on ".$host." user=".$this->searchUser,LOG_DEBUG);
-					$this->result=$this->bindauth($this->searchUser,$this->searchPassword);
-					if ($this->result)
-					{
-						$this->bind=$this->result;
-						$connected=2;
-						break;
-					}
-					else
-					{
-						$this->error=ldap_errno($this->connection).' '.ldap_error($this->connection);
-					}
+					$this->connection = ldap_connect($host);
 				}
 				else
 				{
-					// Try in auth mode
-					if ($this->searchUser && $this->searchPassword)
+					$this->connection = ldap_connect($host,$this->serverPort);
+				}
+	
+				if (is_resource($this->connection))
+				{
+					// Begin TLS if requested by the configuration
+	    			if (! empty($conf->global->LDAP_SERVER_USE_TLS)) 
+	    			{
+	    			    if (! ldap_start_tls($this->connection)) 
+	    			    {
+	    			        dol_syslog(get_class($this)."::connect_bind failed to start tls", LOG_WARNING);
+	    			        $connected = 0;
+	    			        $this->close();
+	    				}
+	    			}
+			
+					// Execute the ldap_set_option here (after connect and before bind)
+					$this->setVersion();
+					ldap_set_option($this->connection, LDAP_OPT_SIZELIMIT, 0); // no limit here. should return true.
+	
+	
+					if ($this->serverType == "activedirectory")
 					{
-						dol_syslog(get_class($this)."::connect_bind try bindauth on ".$host." user=".$this->searchUser,LOG_DEBUG);
+						$result=$this->setReferrals();
+						dol_syslog(get_class($this)."::connect_bind try bindauth for activedirectory on ".$host." user=".$this->searchUser." password=".preg_replace('/./','*',$this->searchPassword),LOG_DEBUG);
 						$this->result=$this->bindauth($this->searchUser,$this->searchPassword);
 						if ($this->result)
 						{
@@ -202,26 +220,45 @@ class Ldap
 							$this->error=ldap_errno($this->connection).' '.ldap_error($this->connection);
 						}
 					}
-					// Try in anonymous
-					if (! $this->bind)
+					else
 					{
-						dol_syslog(get_class($this)."::connect_bind try bind on ".$host,LOG_DEBUG);
-						$result=$this->bind();
-						if ($result)
+						// Try in auth mode
+						if ($this->searchUser && $this->searchPassword)
 						{
-							$this->bind=$this->result;
-							$connected=1;
-							break;
+							dol_syslog(get_class($this)."::connect_bind try bindauth on ".$host." user=".$this->searchUser." password=".preg_replace('/./','*',$this->searchPassword),LOG_DEBUG);
+							$this->result=$this->bindauth($this->searchUser,$this->searchPassword);
+							if ($this->result)
+							{
+								$this->bind=$this->result;
+								$connected=2;
+								break;
+							}
+							else
+							{
+								$this->error=ldap_errno($this->connection).' '.ldap_error($this->connection);
+							}
 						}
-						else
+						// Try in anonymous
+						if (! $this->bind)
 						{
-							$this->error=ldap_errno($this->connection).' '.ldap_error($this->connection);
+							dol_syslog(get_class($this)."::connect_bind try bind on ".$host,LOG_DEBUG);
+							$result=$this->bind();
+							if ($result)
+							{
+								$this->bind=$this->result;
+								$connected=1;
+								break;
+							}
+							else
+							{
+								$this->error=ldap_errno($this->connection).' '.ldap_error($this->connection);
+							}
 						}
 					}
 				}
+	
+				if (! $connected) $this->close();
 			}
-
-			if (! $connected) $this->close();
 		}
 
 		if ($connected)
@@ -335,7 +372,7 @@ class Ldap
 	/**
 	 * Change ldap protocol version to use.
 	 *
-	 * @return	string					version
+	 * @return	boolean					version
 	 */
 	function setVersion() {
 		// LDAP_OPT_PROTOCOL_VERSION est une constante qui vaut 17
@@ -346,7 +383,7 @@ class Ldap
 	/**
 	 * changement du referrals.
 	 *
-	 * @return	string					referrals
+	 * @return	boolean					referrals
 	 */
 	function setReferrals() {
 		// LDAP_OPT_REFERRALS est une constante qui vaut ?
@@ -359,10 +396,10 @@ class Ldap
 	 * 	Add a LDAP entry
 	 *	Ldap object connect and bind must have been done
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@param	User	$user		Objet user that create
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@param	User		$user		Objet user that create
+	 *	@return	int						<0 if KO, >0 if OK
 	 */
 	function add($dn, $info, $user)
 	{
@@ -401,9 +438,10 @@ class Ldap
 		}
 		else
 		{
-			$this->error=@ldap_error($this->connection);
-			$this->errno=@ldap_errno($this->connection);
-			dol_syslog(get_class($this)."::add failed: ".$this->errno." ".$this->error, LOG_ERR);
+			$this->ldapErrorCode = @ldap_errno($this->connection);
+			$this->ldapErrorText = @ldap_error($this->connection);
+			$this->error=$this->ldapErrorCode." ".$this->ldapErrorText;
+			dol_syslog(get_class($this)."::add failed: ".$this->error, LOG_ERR);
 			return -1;
 		}
 	}
@@ -413,7 +451,7 @@ class Ldap
 	 *	Ldap object connect and bind must have been done
 	 *
 	 *	@param	string		$dn			DN entry key
-	 *	@param	string		$info		Attributes array
+	 *	@param	array		$info		Attributes array
 	 *	@param	string		$user		Objet user that modify
 	 *	@return	int						<0 if KO, >0 if OK
 	 */
@@ -465,7 +503,7 @@ class Ldap
 	 *	Ldap object connect and bind must have been done
 	 *
 	 *  @param	string		$dn			DN entry key
-	 *  @param  string		$info		Attributes array
+	 *  @param  array		$info		Attributes array
 	 *  @param  User		$user		Objet user that update
 	 * 	@param	string		$olddn		Old DN entry key (before update)
 	 *	@return	int						<0 if KO, >0 if OK
@@ -552,9 +590,9 @@ class Ldap
 	/**
 	 * 	Build a LDAP message
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@return	string				Content of file
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@return	string					Content of file
 	 */
 	function dump_content($dn, $info)
 	{
@@ -594,9 +632,9 @@ class Ldap
 	/**
 	 * 	Dump a LDAP message to ldapinput.in file
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@return	int						<0 if KO, >0 if OK
 	 */
 	function dump($dn, $info)
 	{
@@ -631,10 +669,10 @@ class Ldap
 	 * 	Add a LDAP attribute in entry
 	 *	Ldap object connect and bind must have been done
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@param	User	$user		Objet user that create
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@param	User		$user		Objet user that create
+	 *	@return	int						<0 if KO, >0 if OK
 	 */
 	function addAttribute($dn, $info, $user)
 	{
@@ -683,10 +721,10 @@ class Ldap
 	 * 	Update a LDAP attribute in entry
 	 *	Ldap object connect and bind must have been done
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@param	User	$user		Objet user that create
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@param	User		$user		Objet user that create
+	 *	@return	int						<0 if KO, >0 if OK
 	 */
 	function updateAttribute($dn, $info, $user)
 	{
@@ -735,10 +773,10 @@ class Ldap
 	 * 	Delete a LDAP attribute in entry
 	 *	Ldap object connect and bind must have been done
 	 *
-	 *	@param	string	$dn			DN entry key
-	 *	@param	string	$info		Attributes array
-	 *	@param	User	$user		Objet user that create
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@param	string		$dn			DN entry key
+	 *	@param	array		$info		Attributes array
+	 *	@param	User		$user		Objet user that create
+	 *	@return	int						<0 if KO, >0 if OK
 	 */
 	function deleteAttribute($dn, $info, $user)
 	{
@@ -788,7 +826,7 @@ class Ldap
 	 *
 	 *	@param	string	$dn			DN entry key
 	 *	@param	string	$filter		Filter
-	 *	@return	int					<0 if KO, >0 if OK
+	 *	@return	int|array			<0 or false if KO, array if OK
 	 */
 	function getAttribute($dn,$filter)
 	{
@@ -813,7 +851,7 @@ class Ldap
 		{
 			$this->ldapErrorCode = -1;
 			$this->ldapErrorText = "Couldn't find entry";
-			return false;  // Couldn't find entry...
+			return 0;  // Couldn't find entry...
 		}
 
 		// Get values
@@ -821,7 +859,7 @@ class Ldap
 		{
 			$this->ldapErrorCode = ldap_errno($this->connection);
 			$this->ldapErrorText = ldap_error($this->connection);
-			return false; // No matching attributes
+			return 0; // No matching attributes
 		}
 
 		// Return an array containing the attributes.
@@ -837,6 +875,7 @@ class Ldap
 	 */
 	function getAttributeValues($filterrecord,$attribute)
 	{
+		$attributes=array();
 		$attributes[0] = $attribute;
 
 		// We need to search for this user in order to get their entry.
@@ -868,14 +907,14 @@ class Ldap
 	}
 
 	/**
-	 * 	Returns an array containing a details of elements
+	 * 	Returns an array containing a details or list of LDAP record(s)
 	 * 	ldapsearch -LLLx -hlocalhost -Dcn=admin,dc=parinux,dc=org -w password -b "ou=adherents,ou=people,dc=parinux,dc=org" userPassword
 	 *
-	 *	@param	string	$search			 	Valeur champ cle recherche, sinon '*' pour tous.
+	 *	@param	string	$search			 	Value of fiel to search, '*' for all. Not used if $activefilter is set.
 	 *	@param	string	$userDn			 	DN (Ex: ou=adherents,ou=people,dc=parinux,dc=org)
 	 *	@param	string	$useridentifier 	Name of key field (Ex: uid)
 	 *	@param	array	$attributeArray 	Array of fields required. Note this array must also contains field $useridentifier (Ex: sn,userPassword)
-	 *	@param	int		$activefilter		1=use field this->filter as filter instead of parameter $search
+	 *	@param	int		$activefilter		'1' or 'user'=use field this->filter as filter instead of parameter $search, 'member'=use field this->filtermember as filter
 	 *	@param	array	$attributeAsArray 	Array of fields wanted as an array not a string
 	 *	@return	array						Array of [id_record][ldap_field]=value
 	 */
@@ -883,7 +922,7 @@ class Ldap
 	{
 		$fulllist=array();
 
-		dol_syslog(get_class($this)."::getRecords search=".$search." userDn=".$userDn." useridentifier=".$useridentifier." attributeArray=array(".join(',',$attributeArray).")");
+		dol_syslog(get_class($this)."::getRecords search=".$search." userDn=".$userDn." useridentifier=".$useridentifier." attributeArray=array(".join(',',$attributeArray).") activefilter=".$activefilter);
 
 		// if the directory is AD, then bind first with the search user first
 		if ($this->serverType == "activedirectory")
@@ -893,15 +932,19 @@ class Ldap
 		}
 
 		// Define filter
-		if ($activefilter == 1)
+		if (! empty($activefilter))
 		{
-			if ($this->filter)
+			if (((string) $activefilter == '1' || (string) $activefilter == 'user') && $this->filter)
 			{
 				$filter = '('.$this->filter.')';
 			}
-			else
+			elseif (((string) $activefilter == 'member') && $this->filter)
 			{
-				$filter='('.$useridentifier.'=*)';
+				$filter = '('.$this->filtermember.')';
+			}
+			else	// If this->filter is empty, make fiter on * (all)
+			{
+				$filter = '('.$useridentifier.'=*)';
 			}
 		}
 		else
@@ -1065,9 +1108,9 @@ class Ldap
 		$subcount = hexdec(substr($hex_sid,2,2));    // Get count of sub-auth entries
 		$auth = hexdec(substr($hex_sid,4,12));      // SECURITY_NT_AUTHORITY
 		$result = "$rev-$auth";
-		for ($x=0;$x < $subcount; $x++) {
-			$subauth[$x] = hexdec($this->littleEndian(substr($hex_sid,16+($x*8),8)));  // get all SECURITY_NT_AUTHORITY
-			$result .= "-".$subauth[$x];
+		for ($x=0;$x < $subcount; $x++)
+		{
+			$result .= "-".hexdec($this->littleEndian(substr($hex_sid,16+($x*8),8)));  // get all SECURITY_NT_AUTHORITY
 		}
 		return $result;
 	}
@@ -1080,9 +1123,9 @@ class Ldap
 	 *	car conflit majuscule-minuscule. A n'utiliser que pour les pages
 	 *	'Fiche LDAP' qui affiche champ lisibles par defaut.
 	 *
-	 * 	@param	string	$checkDn		DN de recherche (Ex: ou=users,cn=my-domain,cn=com)
-	 * 	@param 	string	$filter			Filtre de recherche (ex: (sn=nom_personne) )
-	 *	@return	array					Tableau des reponses (cle en minuscule-valeur)
+	 * 	@param	string		$checkDn		DN de recherche (Ex: ou=users,cn=my-domain,cn=com)
+	 * 	@param 	string		$filter			Search filter (ex: (sn=nom_personne) )
+	 *	@return	array|int					Array with answers (key lowercased - value)
 	 */
 	function search($checkDn, $filter)
 	{
@@ -1298,7 +1341,7 @@ class Ldap
 	 *	Convertit le temps ActiveDirectory en Unix timestamp
 	 *
 	 *	@param	string	$value		AD time to convert
-	 *	@return	string				Unix timestamp
+	 *	@return	integer				Unix timestamp
 	 */
 	function convert_time($value)
 	{
@@ -1370,4 +1413,3 @@ class Ldap
 }
 
 
-?>
\ No newline at end of file
