@@ -1,12 +1,13 @@
 <?php
 /* Copyright (C) 2001		Fabien Seisen			<seisen@linuxfr.org>
  * Copyright (C) 2002-2005	Rodolphe Quiedeville	<rodolphe@quiedeville.org>
- * Copyright (C) 2004-2012	Laurent Destailleur		<eldy@users.sourceforge.net>
+ * Copyright (C) 2004-2014	Laurent Destailleur		<eldy@users.sourceforge.net>
  * Copyright (C) 2004		Sebastien Di Cintio		<sdicintio@ressource-toi.org>
  * Copyright (C) 2004		Benoit Mortier			<benoit.mortier@opensides.be>
  * Copyright (C) 2005-2012	Regis Houssin			<regis.houssin@capnetworks.com>
  * Copyright (C) 2012		Yann Droneaud			<yann@droneaud.fr>
  * Copyright (C) 2012		Florian Henry			<florian.henry@open-concept.pro>
+ * Copyright (C) 2015       Marcos García           <marcosgdf@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,40 +35,21 @@ require_once DOL_DOCUMENT_ROOT .'/core/db/DoliDB.class.php';
  */
 class DoliDBPgsql extends DoliDB
 {
-    //! Database handler
-    var $db;
     //! Database type
 	public $type='pgsql';            // Name of manager
     //! Database label
-	static $label='PostgreSQL';      // Label of manager
+	const LABEL='PostgreSQL';      // Label of manager
 	//! Charset
 	var $forcecharset='UTF8';       // Can't be static as it may be forced with a dynamic value
     //! Collate used to force collate when creating database
     var $forcecollate='';			// Can't be static as it may be forced with a dynamic value
 	//! Version min database
-	static $versionmin=array(8,4,0);	// Version min database
-
-	//! Resultset of last request
+	const VERSIONMIN='9.0.0';	// Version min database
+	/** @var resource Resultset of last query */
 	private $_results;
 
-	var $connected;               // 1 si connecte, 0 sinon
-	var $database_selected;       // 1 si base selectionne, 0 sinon
-	var $database_name;			//! Nom base selectionnee
-	var $database_user;	   		//! Nom user base
-	//! >=1 if a transaction is opened, 0 otherwise
-	var $transaction_opened;
-	var $lastquery;
-	// Saved last error
-	var $lastqueryerror;
-	var $lasterror;
-	var $lasterrno;
-
-	var $unescapeslashquot=0;              // By default we do not force the unescape of \'. This is used only to process sql with mysql escaped data.
-	var $standard_conforming_strings=1;    // Database has option standard_conforming_strings to on
-
-	var $ok;
-	var $error;
-
+	public $unescapeslashquot;
+	public $standard_conforming_strings;
 
 	/**
 	 *	Constructor.
@@ -79,16 +61,18 @@ class DoliDBPgsql extends DoliDB
 	 *	@param	    string	$pass		Mot de passe
 	 *	@param	    string	$name		Nom de la database
 	 *	@param	    int		$port		Port of database server
-	 *	@return	    int					1 if OK, 0 if not
 	 */
 	function __construct($type, $host, $user, $pass, $name='', $port=0)
 	{
 		global $conf,$langs;
 
+        // Note that having "static" property for "$forcecharset" and "$forcecollate" will make error here in strict mode, so they are not static
 		if (! empty($conf->db->character_set)) $this->forcecharset=$conf->db->character_set;
 		if (! empty($conf->db->dolibarr_main_db_collation))	$this->forcecollate=$conf->db->dolibarr_main_db_collation;
 
 		$this->database_user=$user;
+        $this->database_host=$host;
+        $this->database_port=$port;
 
 		$this->transaction_opened=0;
 
@@ -96,8 +80,8 @@ class DoliDBPgsql extends DoliDB
 
 		if (! function_exists("pg_connect"))
 		{
-			$this->connected = 0;
-			$this->ok = 0;
+			$this->connected = false;
+			$this->ok = false;
 			$this->error="Pgsql PHP functions are not available in this version of PHP";
 			dol_syslog(get_class($this)."::DoliDBPgsql : Pgsql PHP functions are not available in this version of PHP",LOG_ERR);
 			return $this->ok;
@@ -105,8 +89,8 @@ class DoliDBPgsql extends DoliDB
 
 		if (! $host)
 		{
-			$this->connected = 0;
-			$this->ok = 0;
+			$this->connected = false;
+			$this->ok = false;
 			$this->error=$langs->trans("ErrorWrongHostParameter");
 			dol_syslog(get_class($this)."::DoliDBPgsql : Erreur Connect, wrong host parameters",LOG_ERR);
 			return $this->ok;
@@ -118,14 +102,14 @@ class DoliDBPgsql extends DoliDB
 
 		if ($this->db)
 		{
-			$this->connected = 1;
-			$this->ok = 1;
+			$this->connected = true;
+			$this->ok = true;
 		}
 		else
 		{
 			// host, login ou password incorrect
-			$this->connected = 0;
-			$this->ok = 0;
+			$this->connected = false;
+			$this->ok = false;
 			$this->error='Host, login or password incorrect';
 			dol_syslog(get_class($this)."::DoliDBPgsql : Erreur Connect ".$this->error,LOG_ERR);
 		}
@@ -135,15 +119,15 @@ class DoliDBPgsql extends DoliDB
 		{
 			if ($this->select_db($name))
 			{
-				$this->database_selected = 1;
+				$this->database_selected = true;
 				$this->database_name = $name;
-				$this->ok = 1;
+				$this->ok = true;
 			}
 			else
 			{
-				$this->database_selected = 0;
+				$this->database_selected = false;
 				$this->database_name = '';
-				$this->ok = 0;
+				$this->ok = false;
 				$this->error=$this->error();
 				dol_syslog(get_class($this)."::DoliDBPgsql : Erreur Select_db ".$this->error,LOG_ERR);
 			}
@@ -151,7 +135,7 @@ class DoliDBPgsql extends DoliDB
 		else
 		{
 			// Pas de selection de base demandee, ok ou ko
-			$this->database_selected = 0;
+			$this->database_selected = false;
 		}
 
 		return $this->ok;
@@ -163,10 +147,10 @@ class DoliDBPgsql extends DoliDB
      *
      *  @param  string	$line   			SQL request line to convert
      *  @param  string	$type				Type of SQL order ('ddl' for insert, update, select, delete or 'dml' for create, alter...)
-     *  @param	string	$unescapeslashquot	Unescape slash quote with quote quote
+     *  @param	bool	$unescapeslashquot	Unescape slash quote with quote quote
      *  @return string   					SQL request line converted
      */
-	static function convertSQLFromMysql($line,$type='auto',$unescapeslashquot=0)
+	static function convertSQLFromMysql($line,$type='auto',$unescapeslashquot=false)
 	{
 		// Removed empty line if this is a comment line for SVN tagging
 		if (preg_match('/^--\s\$Id/i',$line)) {
@@ -179,10 +163,13 @@ class DoliDBPgsql extends DoliDB
 		}
 		if ($line != "")
 		{
-			// group_concat support (PgSQL >= 9.1)
-			$line = preg_replace('/GROUP_CONCAT/i', 'STRING_AGG', $line);
+			// group_concat support (PgSQL >= 9.0)
+			// Replace group_concat(x) or group_concat(x SEPARATOR ',') with string_agg(x, ',')
+		    $line = preg_replace('/GROUP_CONCAT/i', 'STRING_AGG', $line);
 			$line = preg_replace('/ SEPARATOR/i', ',', $line);
-
+			$line = preg_replace('/STRING_AGG\(([^,\)]+)\)/i', 'STRING_AGG(\\1, \',\')', $line);
+			//print $line."\n";
+					
 		    if ($type == 'auto')
 		    {
               if (preg_match('/ALTER TABLE/i',$line)) $type='dml';
@@ -224,6 +211,8 @@ class DoliDBPgsql extends DoliDB
     			$line=preg_replace('/tinytext/i','text',$line);
     			$line=preg_replace('/mediumtext/i','text',$line);
 
+    			$line=preg_replace('/text\([0-9]+\)/i','text',$line);
+
     			// change not null datetime field to null valid ones
     			// (to support remapping of "zero time" to null
     			$line=preg_replace('/datetime not null/i','datetime',$line);
@@ -271,7 +260,7 @@ class DoliDBPgsql extends DoliDB
                     $newreg3=preg_replace('/ NOT NULL/i','',$newreg3);
                     $newreg3=preg_replace('/ NULL/i','',$newreg3);
                     $newreg3=preg_replace('/ DEFAULT 0/i','',$newreg3);
-                    $newreg3=preg_replace('/ DEFAULT \'[0-9a-zA-Z_@]*\'/i','',$newreg3);
+                    $newreg3=preg_replace('/ DEFAULT \'?[0-9a-zA-Z_@]*\'?/i','',$newreg3);
                     $line.= "ALTER TABLE ".$reg[1]." ALTER COLUMN ".$reg[2]." TYPE ".$newreg3;
                     // TODO Add alter to set default value or null/not null if there is this in $reg[3]
                 }
@@ -316,6 +305,9 @@ class DoliDBPgsql extends DoliDB
             $line=str_replace(' LIKE \'',' ILIKE \'',$line);
             $line=str_replace(' LIKE BINARY \'',' LIKE \'',$line);
 
+            // Replace INSERT IGNORE into INSERT
+            $line=preg_replace('/^INSERT IGNORE/','INSERT',$line);
+
 			// Delete using criteria on other table must not declare twice the deleted table
 			// DELETE FROM tabletodelete USING tabletodelete, othertable -> DELETE FROM tabletodelete USING othertable
 			if (preg_match('/DELETE FROM ([a-z_]+) USING ([a-z_]+), ([a-z_]+)/i',$line,$reg))
@@ -364,7 +356,7 @@ class DoliDBPgsql extends DoliDB
      *  On compare juste manuellement si la database choisie est bien celle activee par la connexion
 	 *
 	 *	@param	    string	$database	Name of database
-	 *	@return	    boolean  		    true if OK, false if KO
+	 *	@return	    bool				true if OK, false if KO
 	 */
 	function select_db($database)
 	{
@@ -379,8 +371,8 @@ class DoliDBPgsql extends DoliDB
 	 *	@param	    string		$login		Login
 	 *	@param	    string		$passwd		Password
 	 *	@param		string		$name		Name of database (not used for mysql, used for pgsql)
-	 *	@param		string		$port		Port of database server
-	 *	@return		resource				Database access handler
+	 *	@param		integer		$port		Port of database server
+	 *	@return		false|resource			Database access handler
 	 *	@see		close
 	 */
 	function connect($host, $login, $passwd, $name, $port=0)
@@ -421,20 +413,11 @@ class DoliDBPgsql extends DoliDB
 			$this->database_name = $name;
 			pg_set_error_verbosity($this->db, PGSQL_ERRORS_VERBOSE);	// Set verbosity to max
 		}
+		pg_query($this->db, "set datestyle = 'ISO, YMD';");
 
 		return $this->db;
 	}
 
-	/**
-	 * Return label of manager
-	 *
-	 * @return			string      Label
-	 */
-	function getLabel()
-	{
-		return $this->label;
-	}
-
 	/**
 	 *	Return version of database server
 	 *
@@ -451,16 +434,6 @@ class DoliDBPgsql extends DoliDB
 		return '';
 	}
 
-	/**
-	 *	Return version of database server into an array
-	 *
-	 *	@return	        array  		Version array
-	 */
-	function getVersionArray()
-	{
-		return explode('.',$this->getVersion());
-	}
-
 	/**
 	 *	Return version of database client driver
 	 *
@@ -468,7 +441,7 @@ class DoliDBPgsql extends DoliDB
 	 */
 	function getDriverInfo()
 	{
-		return '';
+		return 'pgsql php driver';
 	}
 
     /**
@@ -482,113 +455,43 @@ class DoliDBPgsql extends DoliDB
         if ($this->db)
         {
           if ($this->transaction_opened > 0) dol_syslog(get_class($this)."::close Closing a connection with an opened transaction depth=".$this->transaction_opened,LOG_ERR);
-          $this->connected=0;
+          $this->connected=false;
           return pg_close($this->db);
         }
         return false;
     }
 
-	/**
-	 * Start transaction
-	 *
-	 * @return	    int         1 if transaction successfuly opened or already opened, 0 if error
-	 */
-	function begin()
-	{
-		if (! $this->transaction_opened)
-		{
-			$ret=$this->query("BEGIN;");
-			if ($ret)
-			{
-				$this->transaction_opened++;
-				dol_syslog("BEGIN Transaction",LOG_DEBUG);
-				dol_syslog('',0,1);
-			}
-			return $ret;
-		}
-		else
-		{
-			$this->transaction_opened++;
-			dol_syslog('',0,1);
-			return 1;
-		}
-	}
-
-	/**
-     * Validate a database transaction
-     *
-     * @param	string	$log        Add more log to default log line
-     * @return  int         		1 if validation is OK or transaction level no started, 0 if ERROR
-	 */
-	function commit($log='')
-	{
-		dol_syslog('',0,-1);
-		if ($this->transaction_opened<=1)
-		{
-			$ret=$this->query("COMMIT;");
-			if ($ret)
-			{
-				$this->transaction_opened=0;
-				dol_syslog("COMMIT Transaction",LOG_DEBUG);
-			}
-			return $ret;
-		}
-		else
-		{
-			$this->transaction_opened--;
-			return 1;
-		}
-	}
-
-	/**
-	 * 	Annulation d'une transaction et retour aux anciennes valeurs
-	 *
-	 * 	@return	    int         1 si annulation ok ou transaction non ouverte, 0 en cas d'erreur
-	 */
-	function rollback()
-	{
-		dol_syslog('',0,-1);
-		if ($this->transaction_opened<=1)
-		{
-			$ret=$this->query("ROLLBACK;");
-			$this->transaction_opened=0;
-			dol_syslog("ROLLBACK Transaction",LOG_DEBUG);
-			return $ret;
-		}
-		else
-		{
-			$this->transaction_opened--;
-			return 1;
-		}
-	}
-
-
 	/**
 	 * Convert request to PostgreSQL syntax, execute it and return the resultset
 	 *
 	 * @param	string	$query			SQL query string
 	 * @param	int		$usesavepoint	0=Default mode, 1=Run a savepoint before and a rollback to savepoint if error (this allow to have some request with errors inside global transactions).
      * @param   string	$type           Type of SQL order ('ddl' for insert, update, select, delete or 'dml' for create, alter...)
-	 * @return	resource    			Resultset of answer
+	 * @return	false|resource			Resultset of answer
 	 */
 	function query($query,$usesavepoint=0,$type='auto')
 	{
+		global $conf;
+
 		$query = trim($query);
 
 		// Convert MySQL syntax to PostgresSQL syntax
 		$query=$this->convertSQLFromMysql($query,$type,($this->unescapeslashquot && $this->standard_conforming_strings));
 		//print "After convertSQLFromMysql:\n".$query."<br>\n";
 
-		// Fix bad formed requests. If request contains a date without quotes, we fix this but this should not occurs.
-		$loop=true;
-		while ($loop)
+		if (! empty($conf->global->MAIN_DB_AUTOFIX_BAD_SQL_REQUEST))
 		{
-			if (preg_match('/([^\'])([0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9])/',$query))
+			// Fix bad formed requests. If request contains a date without quotes, we fix this but this should not occurs.
+			$loop=true;
+			while ($loop)
 			{
-				$query=preg_replace('/([^\'])([0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9])/','\\1\'\\2\'',$query);
-				dol_syslog("Warning: Bad formed request converted into ".$query,LOG_WARNING);
+				if (preg_match('/([^\'])([0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9])/',$query))
+				{
+					$query=preg_replace('/([^\'])([0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9] [0-9][0-9]:[0-9][0-9]:[0-9][0-9])/','\\1\'\\2\'',$query);
+					dol_syslog("Warning: Bad formed request converted into ".$query,LOG_WARNING);
+				}
+				else $loop=false;
 			}
-			else $loop=false;
 		}
 
 		if ($usesavepoint && $this->transaction_opened)
@@ -596,7 +499,10 @@ class DoliDBPgsql extends DoliDB
 			@pg_query($this->db, 'SAVEPOINT mysavepoint');
 		}
 
+		if (! in_array($query,array('BEGIN','COMMIT','ROLLBACK'))) dol_syslog('sql='.$query, LOG_DEBUG);
+
 		$ret = @pg_query($this->db, $query);
+
 		//print $query;
 		if (! preg_match("/^COMMIT/i",$query) && ! preg_match("/^ROLLBACK/i",$query)) // Si requete utilisateur, on la sauvegarde ainsi que son resultset
 		{
@@ -607,10 +513,11 @@ class DoliDBPgsql extends DoliDB
     				$this->lastqueryerror = $query;
     				$this->lasterror = $this->error();
     				$this->lasterrno = $this->errno();
+
+    				if ($conf->global->SYSLOG_LEVEL < LOG_DEBUG) dol_syslog(get_class($this)."::query SQL Error query: ".$query, LOG_ERR);	// Log of request was not yet done previously
+					dol_syslog(get_class($this)."::query SQL Error message: ".$this->lasterror." (".$this->lasterrno.")", LOG_ERR);
+					dol_syslog(get_class($this)."::query SQL Error usesavepoint = ".$usesavepoint, LOG_ERR);
 			    }
-				dol_syslog(get_class($this)."::query SQL error usesavepoint = ".$usesavepoint." - ".$query." - ".pg_last_error($this->db)." => ".$this->errno(), LOG_WARNING);
-				//print "\n>> ".$query."<br>\n";
-				//print '>> '.$this->lasterrno.' - '.$this->lasterror.' - '.$this->lastqueryerror."<br>\n";
 
 				if ($usesavepoint && $this->transaction_opened)	// Warning, after that errno will be erased
 				{
@@ -627,8 +534,8 @@ class DoliDBPgsql extends DoliDB
 	/**
 	 *	Renvoie la ligne courante (comme un objet) pour le curseur resultset
 	 *
-	 *	@param	Resultset	$resultset  Curseur de la requete voulue
-	 *	@return	Object 					Object result line or false if KO or end of cursor
+	 *	@param	resource	$resultset  Curseur de la requete voulue
+	 *	@return	false|object			Object result line or false if KO or end of cursor
 	 */
 	function fetch_object($resultset)
 	{
@@ -640,8 +547,8 @@ class DoliDBPgsql extends DoliDB
 	/**
      *	Return datas as an array
      *
-     *	@param	Resultset	$resultset  Resultset of request
-     *	@return	array					Array
+     *	@param	resource	$resultset  Resultset of request
+     *	@return	false|array				Array
 	 */
 	function fetch_array($resultset)
 	{
@@ -653,8 +560,8 @@ class DoliDBPgsql extends DoliDB
 	/**
      *	Return datas as an array
      *
-     *	@param	Resultset	$resultset  Resultset of request
-     *	@return	array					Array
+     *	@param	resource	$resultset  Resultset of request
+     *	@return	false|array				Array
 	 */
 	function fetch_row($resultset)
 	{
@@ -666,8 +573,8 @@ class DoliDBPgsql extends DoliDB
 	/**
      *	Return number of lines for result of a SELECT
      *
-     *	@param	Resultset	$resultset  Resulset of requests
-     *	@return int		    			Nb of lines
+     *	@param	resourse	$resultset  Resulset of requests
+     *	@return int		    			Nb of lines, -1 on error
      *	@see    affected_rows
 	 */
 	function num_rows($resultset)
@@ -680,7 +587,7 @@ class DoliDBPgsql extends DoliDB
 	/**
 	 * Renvoie le nombre de lignes dans le resultat d'une requete INSERT, DELETE ou UPDATE
 	 *
-	 * @param	Resultset	$resultset  Result set of request
+	 * @param	resource	$resultset  Result set of request
 	 * @return  int		    			Nb of lines
 	 * @see 	num_rows
 	 */
@@ -697,10 +604,10 @@ class DoliDBPgsql extends DoliDB
 	/**
 	 * Libere le dernier resultset utilise sur cette connexion
 	 *
-	 * @param	Resultset	$resultset  Result set of request
+	 * @param	resource	$resultset  Result set of request
 	 * @return	void
 	 */
-	function free($resultset=0)
+	function free($resultset=null)
 	{
         // If resultset not provided, we take the last used by connexion
 		if (! is_resource($resultset)) { $resultset=$this->_results; }
@@ -726,37 +633,6 @@ class DoliDBPgsql extends DoliDB
 	}
 
 
-	/**
-	 * Define sort criteria of request
-	 *
-	 * @param	string	$sortfield  List of sort fields
-	 * @param	string	$sortorder  Sort order
-	 * @return	string      		String to provide syntax of a sort sql string
-	 * TODO		Mutualized this into a mother class
-	 */
-	function order($sortfield=0,$sortorder=0)
-	{
-		if ($sortfield)
-		{
-			$return='';
-			$fields=explode(',',$sortfield);
-			foreach($fields as $val)
-			{
-				if (! $return) $return.=' ORDER BY ';
-				else $return.=',';
-
-				$return.=preg_replace('/[^0-9a-z_\.]/i','',$val);
-                if ($sortorder) $return.=' '.preg_replace('/[^0-9a-z]/i','',$sortorder);
-			}
-			return $return;
-		}
-		else
-		{
-			return '';
-		}
-	}
-
-
 	/**
 	 *   Escape a string to insert data
 	 *
@@ -780,21 +656,6 @@ class DoliDBPgsql extends DoliDB
 		return dol_print_date($param,"%Y-%m-%d %H:%M:%S");
 	}
 
-	/**
-	 *	Convert (by PHP) a PHP server TZ string date into a GM Timestamps date
-	 * 	19700101020000 -> 3600 with TZ+1
-	 *
-	 * 	@param		string	$string		Date in a string (YYYYMMDDHHMMSS, YYYYMMDD, YYYY-MM-DD HH:MM:SS)
-	 *	@return		date				Date TMS
-	 */
-	function jdate($string)
-	{
-		$string=preg_replace('/([^0-9])/i','',$string);
-		$tmp=$string.'000000';
-		$date=dol_mktime(substr($tmp,8,2),substr($tmp,10,2),substr($tmp,12,2),substr($tmp,4,2),substr($tmp,6,2),substr($tmp,0,4));
-		return $date;
-	}
-
 	/**
      *  Format a SQL IF
      *
@@ -808,51 +669,10 @@ class DoliDBPgsql extends DoliDB
 		return '(CASE WHEN '.$test.' THEN '.$resok.' ELSE '.$resko.' END)';
 	}
 
-
-	/**
-	 * Renvoie la derniere requete soumise par la methode query()
-	 *
-	 * @return	    lastquery
-	 */
-	function lastquery()
-	{
-		return $this->lastquery;
-	}
-
-	/**
-	 * Renvoie la derniere requete en erreur
-	 *
-	 * @return	    string	lastqueryerror
-	 */
-	function lastqueryerror()
-	{
-		return $this->lastqueryerror;
-	}
-
-	/**
-	 * Renvoie le libelle derniere erreur
-	 *
-	 * @return	    string	lasterror
-	 */
-	function lasterror()
-	{
-		return $this->lasterror;
-	}
-
-	/**
-	 * 	Renvoie le code derniere erreur
-	 *
-	 * 	@return	    string	lasterrno
-	 */
-	function lasterrno()
-	{
-		return $this->lasterrno;
-	}
-
 	/**
 	 * Renvoie le code erreur generique de l'operation precedente.
 	 *
-	 * @return    error_num       (Exemples: DB_ERROR_TABLE_ALREADY_EXISTS, DB_ERROR_RECORD_ALREADY_EXISTS...)
+	 * @return	string		Error code (Exemples: DB_ERROR_TABLE_ALREADY_EXISTS, DB_ERROR_RECORD_ALREADY_EXISTS...)
 	 */
 	function errno()
 	{
@@ -918,7 +738,7 @@ class DoliDBPgsql extends DoliDB
 	/**
 	 * Renvoie le texte de l'erreur pgsql de l'operation precedente
 	 *
-	 * @return		error_text
+	 * @return	string		Error text
 	 */
 	function error()
 	{
@@ -930,7 +750,7 @@ class DoliDBPgsql extends DoliDB
 	 *
 	 * @param   string	$tab    	Table name concerned by insert. Ne sert pas sous MySql mais requis pour compatibilite avec Postgresql
 	 * @param	string	$fieldid	Field name
-	 * @return  int     			Id of row
+	 * @return  string     			Id of row
 	 */
 	function last_insert_id($tab,$fieldid='rowid')
 	{
@@ -952,7 +772,7 @@ class DoliDBPgsql extends DoliDB
      *
      *  @param  string  $fieldorvalue   Field name or value to encrypt
      *  @param	int		$withQuotes     Return string with quotes
-     *  @return return          		XXX(field) or XXX('value') or field or 'value'
+     *  @return string          		XXX(field) or XXX('value') or field or 'value'
 	 */
 	function encrypt($fieldorvalue, $withQuotes=0)
 	{
@@ -1011,7 +831,7 @@ class DoliDBPgsql extends DoliDB
 	 * 	@param	string	$charset		Charset used to store data
 	 * 	@param	string	$collation		Charset used to sort data
 	 * 	@param	string	$owner			Username of database owner
-	 * 	@return	resource				resource defined if OK, null if KO
+	 * 	@return	false|resource				resource defined if OK, null if KO
 	 */
 	function DDLCreateDb($database,$charset='',$collation='',$owner='')
 	{
@@ -1031,8 +851,8 @@ class DoliDBPgsql extends DoliDB
 	 *  List tables into a database
 	 *
 	 *  @param	string		$database	Name of database
-	 *  @param	string		$table		Nmae of table filter ('xxx%')
-	 *  @return	resource				Resource
+	 *  @param	string		$table		Name of table filter ('xxx%')
+	 *  @return	array					List of tables in an array
 	 */
 	function DDLListTables($database, $table='')
 	{
@@ -1045,7 +865,7 @@ class DoliDBPgsql extends DoliDB
 		{
 			$listtables[] = $row[0];
 		}
-		return  $listtables;
+		return $listtables;
 	}
 
 	/**
@@ -1057,31 +877,34 @@ class DoliDBPgsql extends DoliDB
 	 */
 	function DDLInfoTable($table)
 	{
-		 $infotables=array();
+		$infotables=array();
 
-		 $sql="SELECT ";
-		 $sql.="	infcol.column_name as \"Column\",";
-		 $sql.="	CASE WHEN infcol.character_maximum_length IS NOT NULL THEN infcol.udt_name || '('||infcol.character_maximum_length||')'";
-		 $sql.="		ELSE infcol.udt_name";
-		 $sql.="	END as \"Type\",";
-		 $sql.="	infcol.collation_name as \"Collation\",";
-		 $sql.="	infcol.is_nullable as \"Null\",";
-		 $sql.="	'' as \"Key\",";
-		 $sql.="	infcol.column_default as \"Default\",";
-		 $sql.="	'' as \"Extra\",";
-		 $sql.="	'' as \"Privileges\"";
-		 $sql.="	FROM information_schema.columns infcol";
-		 $sql.="	WHERE table_schema='public' ";
-		 $sql.="	AND table_name='".$table."'";
-		 $sql.="	ORDER BY ordinal_position;";
+		$sql="SELECT ";
+		$sql.="	infcol.column_name as \"Column\",";
+		$sql.="	CASE WHEN infcol.character_maximum_length IS NOT NULL THEN infcol.udt_name || '('||infcol.character_maximum_length||')'";
+		$sql.="		ELSE infcol.udt_name";
+		$sql.="	END as \"Type\",";
+		$sql.="	infcol.collation_name as \"Collation\",";
+		$sql.="	infcol.is_nullable as \"Null\",";
+		$sql.="	'' as \"Key\",";
+		$sql.="	infcol.column_default as \"Default\",";
+		$sql.="	'' as \"Extra\",";
+		$sql.="	'' as \"Privileges\"";
+		$sql.="	FROM information_schema.columns infcol";
+		$sql.="	WHERE table_schema='public' ";
+		$sql.="	AND table_name='".$table."'";
+		$sql.="	ORDER BY ordinal_position;";
 
-		 dol_syslog($sql,LOG_DEBUG);
-		 $result = $this->query($sql);
-		 while($row = $this->fetch_row($result))
-		 {
-			$infotables[] = $row;
-		 }
-		return $infotables;
+		dol_syslog($sql,LOG_DEBUG);
+		$result = $this->query($sql);
+		if ($result)
+		{
+    		 while($row = $this->fetch_row($result))
+    		 {
+    			$infotables[] = $row;
+    		 }
+		}
+        return $infotables;
 	}
 
 
@@ -1094,11 +917,13 @@ class DoliDBPgsql extends DoliDB
 	 *	@param	    string	$type 			Type de la table
 	 *	@param	    array	$unique_keys 	Tableau associatifs Nom de champs qui seront clef unique => valeur
 	 *	@param	    array	$fulltext_keys	Tableau des Nom de champs qui seront indexes en fulltext
-	 *	@param	    string	$keys 			Tableau des champs cles noms => valeur
+	 *	@param	    array	$keys 			Tableau des champs cles noms => valeur
 	 *	@return	    int						<0 if KO, >=0 if OK
 	 */
-	function DDLCreateTable($table,$fields,$primary_key,$type,$unique_keys="",$fulltext_keys="",$keys="")
+	function DDLCreateTable($table,$fields,$primary_key,$type,$unique_keys=null,$fulltext_keys=null,$keys=null)
 	{
+		// FIXME: $fulltext_keys parameter is unused
+
 		// cles recherchees dans le tableau des descriptions (fields) : type,value,attribute,null,default,extra
 		// ex. : $fields['rowid'] = array('type'=>'int','value'=>'11','null'=>'not null','extra'=> 'auto_increment');
 		$sql = "create table ".$table."(";
@@ -1128,7 +953,7 @@ class DoliDBPgsql extends DoliDB
 		if($primary_key != "")
 		$pk = "primary key(".$primary_key.")";
 
-		if($unique_keys != "")
+		if(is_array($unique_keys))
 		{
 			$i = 0;
 			foreach($unique_keys as $key => $value)
@@ -1137,7 +962,7 @@ class DoliDBPgsql extends DoliDB
 				$i++;
 			}
 		}
-		if($keys != "")
+		if(is_array($keys))
 		{
 			$i = 0;
 			foreach($keys as $key => $value)
@@ -1149,9 +974,9 @@ class DoliDBPgsql extends DoliDB
 		$sql .= implode(',',$sqlfields);
 		if($primary_key != "")
 		$sql .= ",".$pk;
-		if($unique_keys != "")
+		if(is_array($unique_keys))
 		$sql .= ",".implode(',',$sqluq);
-		if($keys != "")
+		if(is_array($keys))
 		$sql .= ",".implode(',',$sqlk);
 		$sql .=") type=".$type;
 
@@ -1165,15 +990,16 @@ class DoliDBPgsql extends DoliDB
 	/**
 	 * 	Create a user to connect to database
 	 *
-	 *	@param	string	$dolibarr_main_db_host 		Ip serveur
-	 *	@param	string	$dolibarr_main_db_user 		Nom user a creer
-	 *	@param	string	$dolibarr_main_db_pass 		Mot de passe user a creer
+	 *	@param	string	$dolibarr_main_db_host 		Ip server
+	 *	@param	string	$dolibarr_main_db_user 		Name of user to create
+	 *	@param	string	$dolibarr_main_db_pass 		Password of user to create
 	 *	@param	string	$dolibarr_main_db_name		Database name where user must be granted
 	 *	@return	int									<0 if KO, >=0 if OK
 	 */
 	function DDLCreateUser($dolibarr_main_db_host,$dolibarr_main_db_user,$dolibarr_main_db_pass,$dolibarr_main_db_name)
 	{
-		$sql = "create user \"".addslashes($dolibarr_main_db_user)."\" with password '".addslashes($dolibarr_main_db_pass)."'";
+		// Note: using ' on user does not works with pgsql
+		$sql = "CREATE USER ".$this->escape($dolibarr_main_db_user)." with password '".$this->escape($dolibarr_main_db_pass)."'";
 
 		dol_syslog(get_class($this)."::DDLCreateUser", LOG_DEBUG);	// No sql to avoid password in log
 		$resql=$this->query($sql);
@@ -1190,7 +1016,7 @@ class DoliDBPgsql extends DoliDB
 	 *
 	 *	@param	string		$table	Name of table
 	 *	@param	string		$field	Optionnel : Name of field if we want description of field
-	 *	@return	resultset			Resultset x (x->attname)
+	 *	@return	false|resource		Resultset x (x->attname)
 	 */
 	function DDLDescTable($table,$field="")
 	{
@@ -1235,8 +1061,7 @@ class DoliDBPgsql extends DoliDB
 
 		dol_syslog($sql,LOG_DEBUG);
 		if(! $this -> query($sql))
-		return -1;
-		else
+			return -1;
 		return 1;
 	}
 
@@ -1261,8 +1086,7 @@ class DoliDBPgsql extends DoliDB
 
 		dol_syslog($sql,LOG_DEBUG);
 		if (! $this->query($sql))
-		return -1;
-		else
+			return -1;
 		return 1;
 	}
 
@@ -1275,14 +1099,14 @@ class DoliDBPgsql extends DoliDB
 	 */
 	function DDLDropField($table,$field_name)
 	{
-		$sql= "ALTER TABLE ".$table." DROP COLUMN `".$field_name."`";
+		$sql= "ALTER TABLE ".$table." DROP COLUMN ".$field_name;
 		dol_syslog($sql,LOG_DEBUG);
 		if (! $this->query($sql))
 		{
 			$this->error=$this->lasterror();
 			return -1;
 		}
-		else return 1;
+		return 1;
 	}
 
 	/**
@@ -1293,8 +1117,12 @@ class DoliDBPgsql extends DoliDB
 	function getDefaultCharacterSetDatabase()
 	{
 		$resql=$this->query('SHOW SERVER_ENCODING');
-		$liste=$this->fetch_array($resql);
-		return $liste['server_encoding'];
+		if ($resql)
+		{
+            $liste=$this->fetch_array($resql);
+		    return $liste['server_encoding'];
+		}
+		else return '';
 	}
 
 	/**
@@ -1309,7 +1137,7 @@ class DoliDBPgsql extends DoliDB
 		if ($resql)
 		{
 			$i = 0;
-			while ($obj = $this->fetch_object($resql) )
+			while ($obj = $this->fetch_object($resql))
 			{
 				$liste[$i]['charset'] = $obj->server_encoding;
 				$liste[$i]['description'] = 'Default database charset';
@@ -1330,8 +1158,12 @@ class DoliDBPgsql extends DoliDB
 	function getDefaultCollationDatabase()
 	{
 		$resql=$this->query('SHOW LC_COLLATE');
-		$liste=$this->fetch_array($resql);
-		return $liste['lc_collate'];
+		if ($resql)
+		{
+		    $liste=$this->fetch_array($resql);
+			return $liste['lc_collate'];
+		}
+		else return '';
 	}
 
 	/**
@@ -1393,11 +1225,14 @@ class DoliDBPgsql extends DoliDB
      */
 	function getPathOfRestore()
 	{
-		$fullpathofdump='/pathtopgrestore/pg_restore';
+		//$tool='pg_restore';
+		$tool='psql';
 
-        if (file_exists('/usr/bin/pg_restore'))
+		$fullpathofdump='/pathtopgrestore/'.$tool;
+
+        if (file_exists('/usr/bin/'.$tool))
         {
-            $fullpathofdump='/usr/bin/pg_restore';
+            $fullpathofdump='/usr/bin/'.$tool;
         }
         else
         {
@@ -1407,7 +1242,7 @@ class DoliDBPgsql extends DoliDB
             {
                 $liste=$this->fetch_array($resql);
                 $basedir=$liste['data_directory'];
-                $fullpathofdump=preg_replace('/data$/','bin',$basedir).'/pg_restore';
+                $fullpathofdump=preg_replace('/data$/','bin',$basedir).'/'.$tool;
             }
         }
 
@@ -1415,25 +1250,45 @@ class DoliDBPgsql extends DoliDB
 	}
 
 	/**
-	 *	Return value of server parameters
+	 * Return value of server parameters
 	 *
-	 * 	@param	string	$filter		Filter list on a particular value
-	 *	@return	string				Value for parameter
+	 * @param	string	$filter		Filter list on a particular value
+	 * @return	array				Array of key-values (key=>value)
 	 */
 	function getServerParametersValues($filter='')
 	{
 		$result=array();
 
 		$resql='select name,setting from pg_settings';
-		if ($filter) $resql.=" WHERE name = '".addslashes($filter)."'";
+		if ($filter) $resql.=" WHERE name = '".$this->escape($filter)."'";
 		$resql=$this->query($resql);
 		if ($resql)
 		{
-			$obj=$this->fetch_object($resql);
-			$result[$obj->name]=$obj->setting;
+			while ($obj=$this->fetch_object($resql)) $result[$obj->name]=$obj->setting;
 		}
 
 		return $result;
 	}
+
+	/**
+	 * Return value of server status
+	 *
+	 * @param	string	$filter		Filter list on a particular value
+	 * @return  array				Array of key-values (key=>value)
+	 */
+	function getServerStatusValues($filter='')
+	{
+		/* This is to return current running requests.
+		$sql='SELECT datname,procpid,current_query FROM pg_stat_activity ORDER BY procpid';
+        if ($filter) $sql.=" LIKE '".$this->escape($filter)."'";
+        $resql=$this->query($sql);
+        if ($resql)
+        {
+            $obj=$this->fetch_object($resql);
+            $result[$obj->Variable_name]=$obj->Value;
+        }
+		*/
+
+		return array();
+	}
 }
-?>
