@@ -1,7 +1,7 @@
 <?php
 /* Copyright (C) 2012      Nicolas Villa aka Boyquotes http://informetic.fr
  * Copyright (C) 2013      Florian Henry <florian.henry@open-concpt.pro>
- * Copyright (C) 2013      Laurent Destailleur <eldy@users.sourceforge.net>
+ * Copyright (C) 2013-2016 Laurent Destailleur <eldy@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,13 @@ $id=GETPOST('id','int');
 $action=GETPOST('action','alpha');
 $confirm=GETPOST('confirm','alpha');
 $cancel=GETPOST('cancel');
+$backtourl=GETPOST('backtourl','alpha');
+$securitykey = GETPOST('securitykey','alpha');
+
+
+/*
+ * Actions
+ */
 
 $object = new Cronjob($db);
 if (!empty($id))
@@ -49,20 +56,28 @@ if (!empty($id))
 	$result=$object->fetch($id);
 	if ($result < 0)
 	{
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 	}
 }
 
-if(!empty($cancel))
+if (!empty($cancel))
 {
-	if (!empty($id))
+    if (!empty($id) && empty($backtourl))
 	{
 		$action='';
 	}
 	else
 	{
-		Header("Location: ".DOL_URL_ROOT.'/cron/list.php?status=1');
-		exit;
+	    if ($backtourl)
+	    {
+	        header("Location: ".$backtourl);
+	        exit;
+	    }
+	    else
+	    {
+	        header("Location: ".DOL_URL_ROOT.'/cron/list.php?status=-2');
+		    exit;
+	    }
 	}
 }
 
@@ -73,12 +88,12 @@ if ($action == 'confirm_delete' && $confirm == "yes" && $user->rights->cron->del
 
 	if ($result < 0)
 	{
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 		$action='edit';
 	}
 	else
 	{
-		Header("Location: ".DOL_URL_ROOT.'/cron/list.php?status=1');
+		Header("Location: ".DOL_URL_ROOT.'/cron/list.php?status=-2');
 		exit;
 	}
 }
@@ -86,28 +101,38 @@ if ($action == 'confirm_delete' && $confirm == "yes" && $user->rights->cron->del
 // Execute jobs
 if ($action == 'confirm_execute' && $confirm == "yes" && $user->rights->cron->execute)
 {
-	$result=$object->run_jobs($user->login);
-
-	if ($result < 0)
-	{
-		setEventMessage($object->error,'errors');
-		$action='';
-	}
-	else
-	{
-		$res = $object->reprogram_jobs($user->login);
-		if ($res > 0)
-		{
-			if ($object->lastresult > 0) setEventMessage($langs->trans("JobFinished"),'warnings');
-			else setEventMessage($langs->trans("JobFinished"),'mesgs');
-			$action='';
-		}
-		else
-		{
-			setEventMessage($object->error,'errors');
-			$action='';
-		}
-	}
+    if (! empty($conf->global->CRON_KEY) && $conf->global->CRON_KEY != $securitykey)
+    {
+        setEventMessages('Security key '.$securitykey.' is wrong', null, 'errors');
+        $action='';
+    }
+    else
+    {
+        $now = dol_now();   // Date we start
+        
+    	$result=$object->run_jobs($user->login);
+    
+    	if ($result < 0)
+    	{
+    		setEventMessages($object->error, $object->errors, 'errors');
+    		$action='';
+    	}
+    	else
+    	{
+    		$res = $object->reprogram_jobs($user->login, $now);
+    		if ($res > 0)
+    		{
+    			if ($object->lastresult > 0) setEventMessages($langs->trans("JobFinished"), null, 'warnings');
+    			else setEventMessages($langs->trans("JobFinished"), null, 'mesgs');
+    			$action='';
+    		}
+    		else
+    		{
+    			setEventMessages($object->error, $object->errors, 'errors');
+    			$action='';
+    		}
+    	}
+    }
 }
 
 
@@ -126,19 +151,21 @@ if ($action=='add')
 	$object->note=GETPOST('note');
 	$object->datestart=dol_mktime(GETPOST('datestarthour','int'), GETPOST('datestartmin','int'), 0, GETPOST('datestartmonth','int'), GETPOST('datestartday','int'), GETPOST('datestartyear','int'));
 	$object->dateend=dol_mktime(GETPOST('dateendhour','int'), GETPOST('dateendmin','int'), 0, GETPOST('dateendmonth','int'), GETPOST('dateendday','int'), GETPOST('dateendyear','int'));
+	$object->datenextrun=dol_mktime(GETPOST('datenextrunhour','int'), GETPOST('datenextrunmin','int'), 0, GETPOST('datenextrunmonth','int'), GETPOST('datenextrunday','int'), GETPOST('datenextrunyear','int'));
 	$object->unitfrequency=GETPOST('unitfrequency','int');
-	$object->frequency=$object->unitfrequency * GETPOST('nbfrequency','int');
-
+	$object->frequency=GETPOST('nbfrequency','int');
+	$object->maxrun=GETPOST('maxrun','int');
+	
 	// Add cron task
 	$result = $object->create($user);
 
 	// test du Resultat de la requete
 	if ($result < 0) {
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 		$action='create';
 	}
 	else {
-		setEventMessage($langs->trans('CronSaveSucess'),'mesgs');
+		setEventMessages($langs->trans('CronSaveSucess'), null, 'mesgs');
 		$action='';
 	}
 }
@@ -160,19 +187,21 @@ if ($action=='update')
 	$object->note=GETPOST('note');
 	$object->datestart=dol_mktime(GETPOST('datestarthour','int'), GETPOST('datestartmin','int'), 0, GETPOST('datestartmonth','int'), GETPOST('datestartday','int'), GETPOST('datestartyear','int'));
 	$object->dateend=dol_mktime(GETPOST('dateendhour','int'), GETPOST('dateendmin','int'), 0, GETPOST('dateendmonth','int'), GETPOST('dateendday','int'), GETPOST('dateendyear','int'));
+	$object->datenextrun=dol_mktime(GETPOST('datenextrunhour','int'), GETPOST('datenextrunmin','int'), 0, GETPOST('datenextrunmonth','int'), GETPOST('datenextrunday','int'), GETPOST('datenextrunyear','int'));
 	$object->unitfrequency=GETPOST('unitfrequency','int');
-	$object->frequency=$object->unitfrequency * GETPOST('nbfrequency','int');
-
+	$object->frequency=GETPOST('nbfrequency','int');
+	$object->maxrun=GETPOST('maxrun','int');
+	
 	// Add cron task
 	$result = $object->update($user);
 
 	// test du Resultat de la requete
 	if ($result < 0) {
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 		$action='edit';
 	}
 	else {
-		setEventMessage($langs->trans('CronSaveSucess'),'mesgs');
+		setEventMessages($langs->trans('CronSaveSucess'), null, 'mesgs');
 		$action='';
 	}
 }
@@ -186,11 +215,11 @@ if ($action=='activate')
 
 	// test du Resultat de la requete
 	if ($result < 0) {
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 		$action='edit';
 	}
 	else {
-		setEventMessage($langs->trans('CronSaveSucess'),'mesgs');
+		setEventMessages($langs->trans('CronSaveSucess'), null, 'mesgs');
 		$action='';
 	}
 }
@@ -204,11 +233,11 @@ if ($action=='inactive')
 
 	// test du Resultat de la requete
 	if ($result < 0) {
-		setEventMessage($object->error,'errors');
+		setEventMessages($object->error, $object->errors, 'errors');
 		$action='edit';
 	}
 	else {
-		setEventMessage($langs->trans('CronSaveSucess'),'mesgs');
+		setEventMessages($langs->trans('CronSaveSucess'), null, 'mesgs');
 		$action='';
 	}
 }
@@ -227,11 +256,10 @@ llxHeader('',$langs->trans("CronAdd"));
 if ($action=='edit' || empty($action) || $action=='delete' || $action=='execute')
 {
 	$head=cron_prepare_head($object);
-	print dol_get_fiche_head($head, 'card', $langs->trans("CronTask"), 0, 'bill');
 }
 elseif ($action=='create')
 {
-	print_fiche_titre($langs->trans("CronTask"),'','setup');
+	print load_fiche_titre($langs->trans("CronTask"),'','title_setup');
 }
 
 if ($conf->use_javascript_ajax)
@@ -265,7 +293,7 @@ if ($action == 'delete')
 }
 
 if ($action == 'execute'){
-	print $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id,$langs->trans("CronExecute"),$langs->trans("CronConfirmExecute"),"confirm_execute",'','',1);
+	print $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id.'&securitykey='.$securitykey,$langs->trans("CronExecute"),$langs->trans("CronConfirmExecute"),"confirm_execute",'','',1);
 
 	$action='';
 }
@@ -278,13 +306,14 @@ if ($action == 'execute'){
 
 if (empty($object->status) && $action != 'create')
 {
-	dol_htmloutput_mesg($langs->trans("CronTaskInactive"),'','warning',1);
+	setEventMessages($langs->trans("CronTaskInactive"), null, 'warnings');
 }
 
 if (($action=="create") || ($action=="edit"))
 {
 	print '<form name="cronform" action="'.$_SERVER["PHP_SELF"].'" method="post">';
 	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">'."\n";
+	print '<input type="hidden" name="backtourl" value="'.GETPOST('backtourl').'">'."\n";
 	if (!empty($object->id)) {
 		print '<input type="hidden" name="action" value="update">'."\n";
 		print '<input type="hidden" name="id" value="'.$object->id.'">'."\n";
@@ -292,9 +321,11 @@ if (($action=="create") || ($action=="edit"))
 		print '<input type="hidden" name="action" value="add">'."\n";
 	}
 
+	dol_fiche_head('');
+
 	print '<table class="border" width="100%">';
 
-	print '<tr><td width="30%">';
+	print '<tr><td class="fieldrequired titlefieldcreate">';
 	print $langs->trans('CronLabel')."</td>";
 	print "<td><input type=\"text\" size=\"20\" name=\"label\" value=\"".$object->label."\" /> ";
 	print "</td>";
@@ -302,7 +333,7 @@ if (($action=="create") || ($action=="edit"))
 	print "</td>";
 	print "</tr>\n";
 
-	print "<tr><td>";
+	print '<tr><td class="fieldrequired">';
 	print $langs->trans('CronType')."</td><td>";
 	print $formCron->select_typejob('jobtype',$object->jobtype);
 	print "</td>";
@@ -310,101 +341,6 @@ if (($action=="create") || ($action=="edit"))
 	print "</td>";
 	print "</tr>\n";
 
-	print "<tr><td>";
-	print $langs->trans('CronHourStart')."</td><td>";
-	if(!empty($object->datestart))
-	{
-		$form->select_date($object->datestart,'datestart',1,1,'',"cronform");
-	}
-	else
-	{
-		$form->select_date('','datestart',1,1,'',"cronform");
-	}
-	print "</td>";
-	print "<td>";
-	print "</td>";
-	print "</tr>\n";
-
-	print "<tr><td>";
-	print $langs->trans('CronDtEnd')."</td><td>";
-	if(!empty($object->dateend)){
-		$form->select_date($object->dateend,'dateend',1,1,'',"cronform");
-	}
-	else{
-		$form->select_date('','dateend',1,1,1,"cronform");
-	}
-	print "</td>";
-	print "<td>";
-	print "</td>";
-	print "</tr>\n";
-
-	print "<tr><td>";
-	print $langs->trans('CronPriority')."</td>";
-	$priority=0;
-	if (!empty($object->priority)) {
-		$priority=$object->priority;
-	}
-	print "<td><input type=\"text\" size=\"2\" name=\"priority\" value=\"".$priority."\" /> ";
-	print "</td>";
-	print "<td>";
-	print "</td>";
-	print "</tr>\n";
-
-	print "<tr><td>";
-	print $langs->trans('CronEvery')."</td>";
-	print "<td><select name=\"nbfrequency\">";
-	for($i=1; $i<=60; $i++){
-		if(($object->frequency/$object->unitfrequency) == $i){
-			print "<option value='".$i."' selected='selected'>".$i."</option>";
-		}
-		else{
-			print "<option value='".$i."'>".$i."</option>";
-		}
-	}
-	$input = "<input type=\"radio\" name=\"unitfrequency\" value=\"60\" id=\"frequency_minute\" ";
-	if($object->unitfrequency=="60"){
-		$input .= ' checked="checked" />';
-	}
-	else{
-		$input .= ' />';
-	}
-	$input .= "<label for=\"frequency_minute\">".$langs->trans('Minutes')."</label>";
-	print $input;
-
-	$input = "<input type=\"radio\" name=\"unitfrequency\" value=\"3600\" id=\"frequency_heures\" ";
-	if($object->unitfrequency=="3600"){
-		$input .= ' checked="checked" />';
-	}
-	else{
-		$input .= ' />';
-	}
-	$input .= "<label for=\"frequency_heures\">".$langs->trans('Hours')."</label>";
-	print $input;
-
-	$input = "<input type=\"radio\" name=\"unitfrequency\" value=\"86400\" id=\"frequency_jours\" ";
-	if($object->unitfrequency=="86400"){
-		$input .= ' checked="checked" />';
-	}
-	else{
-		$input .= ' />';
-	}
-	$input .= "<label for=\"frequency_jours\">".$langs->trans('Days')."</label>";
-	print $input;
-
-	$input = "<input type=\"radio\" name=\"unitfrequency\" value=\"604800\" id=\"frequency_semaine\" ";
-	if($object->unitfrequency=="604800"){
-		$input .= ' checked="checked" />';
-	}
-	else{
-		$input .= ' />';
-	}
-	$input .= "<label for=\"frequency_semaine\">".$langs->trans('Weeks')."</label>";
-	print $input;
-	print "</td>";
-	print "<td>";
-	print "</td>";
-	print "</tr>\n";
-
 	print '<tr class="blockmethod"><td>';
 	print $langs->trans('CronModule')."</td><td>";
 	print "<input type=\"text\" size=\"20\" name=\"module_name\" value=\"".$object->module_name."\" /> ";
@@ -468,32 +404,171 @@ if (($action=="create") || ($action=="edit"))
 	print "</td>";
 	print "</tr>\n";
 
+	print '<tr><td class="fieldrequired">';
+	print $langs->trans('CronEvery')."</td>";
+	print "<td>";
+	print "<select name=\"nbfrequency\">";
+	for($i=1; $i<=60; $i++)
+	{
+	    if (! empty($object->unitfrequency) && ($object->frequency/$object->unitfrequency) == $i)
+	    {
+	        print "<option value='".$i."' selected>".$i."</option>";
+	    }
+	    else
+	    {
+	        print "<option value='".$i."'>".$i."</option>";
+	    }
+	}
+	print "</select>";
+	$input = " <input type=\"radio\" name=\"unitfrequency\" value=\"60\" id=\"frequency_minute\" ";
+	if($object->unitfrequency=="60")
+	{
+	    $input .= ' checked />';
+	}
+	else{
+	    $input .= ' />';
+	}
+	$input .= "<label for=\"frequency_minute\">".$langs->trans('Minutes')."</label>";
+	print $input;
+	
+	$input = " <input type=\"radio\" name=\"unitfrequency\" value=\"3600\" id=\"frequency_heures\" ";
+	if($object->unitfrequency=="3600"){
+	    $input .= ' checked />';
+	}
+	else{
+	    $input .= ' />';
+	}
+	$input .= "<label for=\"frequency_heures\">".$langs->trans('Hours')."</label>";
+	print $input;
+	
+	$input = " <input type=\"radio\" name=\"unitfrequency\" value=\"86400\" id=\"frequency_jours\" ";
+	if($object->unitfrequency=="86400"){
+	    $input .= ' checked />';
+	}
+	else{
+	    $input .= ' />';
+	}
+	$input .= "<label for=\"frequency_jours\">".$langs->trans('Days')."</label>";
+	print $input;
+	
+	$input = " <input type=\"radio\" name=\"unitfrequency\" value=\"604800\" id=\"frequency_semaine\" ";
+	if($object->unitfrequency=="604800"){
+	    $input .= ' checked />';
+	}
+	else{
+	    $input .= ' />';
+	}
+	$input .= "<label for=\"frequency_semaine\">".$langs->trans('Weeks')."</label>";
+	print $input;
+	print "</td>";
+	print "<td>";
+	print "</td>";
+	print "</tr>\n";
+	
+	print "<tr><td>";
+	print $langs->trans('CronDtStart')."</td><td>";
+	if(!empty($object->datestart))
+	{
+	    $form->select_date($object->datestart,'datestart',1,1,'',"cronform");
+	}
+	else
+	{
+	    $form->select_date('','datestart',1,1,'',"cronform");
+	}
+	print "</td>";
+	print "<td>";
+	print "</td>";
+	print "</tr>\n";
+	
+	print "<tr><td>";
+	print $langs->trans('CronDtEnd')."</td><td>";
+	if(!empty($object->dateend)){
+	    $form->select_date($object->dateend,'dateend',1,1,'',"cronform");
+	}
+	else{
+	    $form->select_date(-1,'dateend',1,1,1,"cronform");
+	}
+	print "</td>";
+	print "<td>";
+	print "</td>";
+	print "</tr>\n";
+	
+	print "<tr><td>";
+	print $langs->trans('CronPriority')."</td>";
+	$priority=0;
+	if (!empty($object->priority)) {
+	    $priority=$object->priority;
+	}
+	print "<td><input type=\"text\" size=\"2\" name=\"priority\" value=\"".$priority."\" /> ";
+	print "</td>";
+	print "<td>";
+	print "</td>";
+	print "</tr>\n";
+	
+	print '<tr><td>';
+	$maxrun='';
+	if (!empty($object->maxrun)) {
+	    $maxrun=$object->maxrun;
+	}
+	print $langs->trans('CronMaxRun')."</td>";
+	print "<td><input type=\"text\" size=\"2\" name=\"maxrun\" value=\"".$maxrun."\" /> ";
+	print "</td>";
+	print "<td>";
+	print "</td>";
+	print "</tr>\n";
+	
+	print '<tr><td>';
+	print $langs->trans('CronDtNextLaunch');
+	print ' ('.$langs->trans('CronFrom').')';
+	print "</td><td>";
+	if(!empty($object->datenextrun))
+	{
+	    $form->select_date($object->datenextrun,'datenextrun',1,1,'',"cronform");
+	}
+	else
+	{
+	    $form->select_date(-1,'datenextrun',1,1,'',"cronform");
+	}	
+	print "</td>";
+    print "<td>";
+	print "</td>";
+	print "</tr>";
+	
 	print '</table>';
 
-	print '<div align="center"><br>';
+	dol_fiche_end();
+
+	print '<div align="center">';
 	print '<input type="submit" name="save" class="button" value="'.$langs->trans("Save").'">';
+	print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
 	print '<input type="submit" name="cancel" class="button" value="'.$langs->trans("Cancel").'">';
-	print "</center>";
+	print "</div>";
 
 	print "</form>\n";
 
-}else {
-
+}
+else
+{
 	/*
-	 * view Template
+	 * view card
 	 */
+    $now = dol_now();
+    
+	dol_fiche_head($head, 'card', $langs->trans("CronTask"), 0, 'cron');
 
+	$linkback = '<a href="' . DOL_URL_ROOT . '/cron/list.php?status=-2">' . $langs->trans("BackToList") . '</a>';
+	
 	// box add_jobs_box
 	print '<table class="border" width="100%">';
 
-	print '<tr><td width="30%">';
+	print '<tr><td class="titlefield">';
 	print $langs->trans('CronId')."</td>";
-	print "<td>".$form->showrefnav($object, 'id', $linkback, 1, 'rowid', 'id');
+	print "<td>".$form->showrefnav($object, 'id', $linkback, 1, 'rowid', 'id', '', '', 0);
 	print "</td></tr>\n";
 
 	print '<tr><td>';
 	print $langs->trans('CronLabel')."</td>";
-	print "<td>".$object->label;
+	print "<td>".$langs->trans($object->label);
 	print "</td></tr>";
 
 	print "<tr><td>";
@@ -501,36 +576,6 @@ if (($action=="create") || ($action=="edit"))
 	print $formCron->select_typejob('jobtype',$object->jobtype,1);
 	print "</td></tr>";
 
-	print "<tr><td>";
-	print $langs->trans('CronHourStart')."</td><td>";
-	if(!empty($object->datestart)) {print dol_print_date($object->datestart,'dayhourtext');} else {print $langs->trans('CronNone');}
-	print "</td></tr>";
-
-	print "<tr><td>";
-	print $langs->trans('CronDtEnd')."</td><td>";
-	if(!empty($object->dateend)) {print dol_print_date($object->dateend,'dayhourtext');} else {print $langs->trans('CronNone');}
-	print "</td></tr>";
-
-	print "<tr><td>";
-	print $langs->trans('CronPriority')."</td>";
-	print "<td>".$object->priority;
-	print "</td></tr>";
-
-	print "<tr><td>";
-	print $langs->trans('CronNbRun')."</td>";
-	print "<td>".$object->nbrun;
-	print "</td></tr>";
-
-	print "<tr><td>";
-	print $langs->trans('CronEvery')."</td>";
-	print "<td>";
-	if($object->unitfrequency == "60") print $langs->trans('CronEach')." ".($object->frequency/$object->unitfrequency)." ".$langs->trans('Minutes');
-	if($object->unitfrequency == "3600") print $langs->trans('CronEach')." ".($object->frequency/$object->unitfrequency)." ".$langs->trans('Hours');
-	if($object->unitfrequency == "86400") print $langs->trans('CronEach')." ".($object->frequency/$object->unitfrequency)." ".$langs->trans('Days');
-	if($object->unitfrequency == "604800") print $langs->trans('CronEach')." ".($object->frequency/$object->unitfrequency)." ".$langs->trans('Weeks');
-	print "</td></tr>";
-
-
 	print '<tr class="blockmethod"><td>';
 	print $langs->trans('CronModule')."</td><td>";
 	print $object->module_name;
@@ -563,22 +608,82 @@ if (($action=="create") || ($action=="edit"))
 
 	print '<tr><td>';
 	print $langs->trans('CronNote')."</td><td>";
-	print $object->note;
+	print $langs->trans($object->note);
 	print "</td></tr>";
 
 	print '<tr><td>';
+	print $langs->trans('Active')."</td><td>";
+	print yn($object->status);
+	print "</td></tr>";
+
+	print '</table>';
+
+	print '<br>';
+
+	
+	print '<table class="border" width="100%">';
+	
+	print '<tr><td class="titlefield">';
+	print $langs->trans('CronEvery')."</td>";
+	print "<td>";
+	if($object->unitfrequency == "60") print $langs->trans('CronEach')." ".($object->frequency)." ".$langs->trans('Minutes');
+	if($object->unitfrequency == "3600") print $langs->trans('CronEach')." ".($object->frequency)." ".$langs->trans('Hours');
+	if($object->unitfrequency == "86400") print $langs->trans('CronEach')." ".($object->frequency)." ".$langs->trans('Days');
+	if($object->unitfrequency == "604800") print $langs->trans('CronEach')." ".($object->frequency)." ".$langs->trans('Weeks');
+	print "</td></tr>";
+	
+	print '<tr><td>';
+	print $langs->trans('CronDtStart')."</td><td>";
+	if(!empty($object->datestart)) {print dol_print_date($object->datestart,'dayhoursec');}
+	print "</td></tr>";
+	
+	print "<tr><td>";
+	print $langs->trans('CronDtEnd')."</td><td>";
+	if(!empty($object->dateend)) {print dol_print_date($object->dateend,'dayhoursec');}
+	print "</td></tr>";
+	
+	print "<tr><td>";
+	print $langs->trans('CronPriority')."</td>";
+	print "<td>".$object->priority;
+	print "</td></tr>";
+	
+	print "<tr><td>";
+	print $langs->trans('CronMaxRun')."</td>";
+	print "<td>";
+	print $object->maxrun>0?$object->maxrun:'';
+	print "</td></tr>";
+	
+	print "<tr><td>";
+	print $langs->trans('CronNbRun')."</td>";
+	print "<td>".$object->nbrun;
+	print "</td></tr>";
+	
+	// Date next run (from)
+	print '<tr><td>';
+	print $langs->trans('CronDtNextLaunch');
+	print ' ('.$langs->trans('CronFrom').')';
+	print "</td><td>";
+	print '<strong>';
+	if (!empty($object->datenextrun)) {print dol_print_date($object->datenextrun,'dayhoursec');} else {print $langs->trans('CronNone');}
+	if ($object->maxnbrun && $object->nbrun >= $object->maxrun) print img_warning($langs->trans("Finished"));
+	if ($object->datenextrun && $object->datenextrun < $now) print img_warning($langs->trans("Late"));
+	print '</strong>';
+	print "</td></tr>";
+	
+	print '</table>';
+	
+	print '<br>';
+	
+	print '<table class="border" width="100%">';
+
+	print '<tr><td class="titlefield">';
 	print $langs->trans('CronDtLastLaunch')."</td><td>";
-	if(!empty($object->datelastrun)) {print dol_print_date($object->datelastrun,'dayhourtext');} else {print $langs->trans('CronNone');}
-	print "</td></tr>";
-
-	print '<tr><td>';
-	print $langs->trans('CronDtNextLaunch')."</td><td>";
-	if(!empty($object->datenextrun)) {print dol_print_date($object->datenextrun,'dayhourtext');} else {print $langs->trans('CronNone');}
+	if(!empty($object->datelastrun)) {print dol_print_date($object->datelastrun,'dayhoursec');} else {print $langs->trans('CronNone');}
 	print "</td></tr>";
 
 	print '<tr><td>';
 	print $langs->trans('CronDtLastResult')."</td><td>";
-	if(!empty($object->datelastresult)) {print dol_print_date($object->datelastresult,'dayhourtext');} else {print $langs->trans('CronNone');}
+	if(!empty($object->datelastresult)) {print dol_print_date($object->datelastresult,'dayhoursec');} else {print $langs->trans('CronNone');}
 	print "</td></tr>";
 
 	print '<tr><td>';
@@ -593,7 +698,6 @@ if (($action=="create") || ($action=="edit"))
 
 	print '</table>';
 
-
 	dol_fiche_end();
 
 
@@ -603,36 +707,40 @@ if (($action=="create") || ($action=="edit"))
 	} else {
 		print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=edit&id='.$object->id.'">'.$langs->trans("Edit").'</a>';
 	}
-	if (! $user->rights->cron->delete) {
-		print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("NotEnoughPermissions")).'">'.$langs->trans("Delete").'</a>';
-	} else {
-		print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=delete&id='.$object->id.'">'.$langs->trans("Delete").'</a>';
-	}
-	if (! $user->rights->cron->create) {
-		print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("NotEnoughPermissions")).'">'.$langs->trans("CronStatusActiveBtn").'/'.$langs->trans("CronStatusInactiveBtn").'</a>';
-	} else {
-		if (empty($object->status)) {
-			print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=activate&id='.$object->id.'">'.$langs->trans("CronStatusActiveBtn").'</a>';
-		} else {
-			print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=inactive&id='.$object->id.'">'.$langs->trans("CronStatusInactiveBtn").'</a>';
-		}
-	}
+
 	if ((empty($user->rights->cron->execute)))
 	{
 		print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("NotEnoughPermissions")).'">'.$langs->trans("CronExecute").'</a>';
 	}
 	else if (empty($object->status))
 	{
-		print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("TaskDisabled")).'">'.$langs->trans("CronExecute").'</a>';
+		print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("JobDisabled")).'">'.$langs->trans("CronExecute").'</a>';
 	}
 	else {
-		print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=execute&id='.$object->id.'">'.$langs->trans("CronExecute").'</a>';
+		print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=execute&id='.$object->id.(empty($conf->global->CRON_KEY)?'':'&securitykey='.$conf->global->CRON_KEY).'">'.$langs->trans("CronExecute").'</a>';
 	}
-	print '<br><br></div>';
+	
+	if (! $user->rights->cron->create) {
+	    print '<a class="butActionRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("NotEnoughPermissions")).'">'.$langs->trans("CronStatusActiveBtn").'/'.$langs->trans("CronStatusInactiveBtn").'</a>';
+	} else {
+	    if (empty($object->status)) {
+	        print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=activate&id='.$object->id.'">'.$langs->trans("CronStatusActiveBtn").'</a>';
+	    } else {
+	        print '<a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?action=inactive&id='.$object->id.'">'.$langs->trans("CronStatusInactiveBtn").'</a>';
+	    }
+	}
+	
+	if (! $user->rights->cron->delete) {
+		print '<a class="butActionDeleteRefused" href="#" title="'.dol_escape_htmltag($langs->transnoentitiesnoconv("NotEnoughPermissions")).'">'.$langs->trans("Delete").'</a>';
+	} else {
+		print '<a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?action=delete&id='.$object->id.'">'.$langs->trans("Delete").'</a>';
+	}
+	print '</div>';
+
+	print '<br>';
 }
 
 
 llxFooter();
 
 $db->close();
-?>
