@@ -32,5 +32,8 @@ create table llx_societe_remise_except
   fk_facture_line		integer,
   fk_facture			integer,
   fk_facture_source		integer,
-  description			varchar(255) NOT NULL
+  description			text NOT NULL,
+  multicurrency_amount_ht	double(24,8) DEFAULT 0 NOT NULL,
+  multicurrency_amount_tva	double(24,8) DEFAULT 0 NOT NULL,
+  multicurrency_amount_ttc	double(24,8) DEFAULT 0 NOT NULL
 )ENGINE=innodb;
