@@ -69,7 +69,7 @@ function llxHeaderPaypal($title, $head = "")
 
 		// JQuery. Must be before other includes
 		print '<!-- Includes JS for JQuery -->'."\n";
-		print '<script type="text/javascript" src="'.DOL_URL_ROOT.'/includes/jquery/js/jquery-latest.min'.$ext.'"></script>'."\n";
+		print '<script type="text/javascript" src="'.DOL_URL_ROOT.'/includes/jquery/js/jquery.min'.$ext.'"></script>'."\n";
 		// jQuery jnotify
 		if (empty($conf->global->MAIN_DISABLE_JQUERY_JNOTIFY))
 		{
@@ -153,11 +153,11 @@ function html_print_paypal_footer($fromcompany,$langs)
 	}
 
 	print '<br><br><hr>'."\n";
-	print '<center><font style="font-size: 10px;">'."\n";
-	print $fromcompany->nom.'<br>';
+	print '<div class="center"><font style="font-size: 10px;">'."\n";
+	print $fromcompany->name.'<br>';
 	print $line1.'<br>';
 	print $line2;
-	print '</font></center>'."\n";
+	print '</font></div>'."\n";
 }
 
 /**
@@ -173,7 +173,7 @@ function paypaladmin_prepare_head()
 	$head = array();
 
 	$head[$h][0] = DOL_URL_ROOT."/paypal/admin/paypal.php";
-	$head[$h][1] = $langs->trans("Account");
+	$head[$h][1] = $langs->trans("PayPal");
 	$head[$h][2] = 'paypalaccount';
 	$h++;
 
@@ -249,8 +249,8 @@ function getPaypalPaymentUrl($mode,$type,$ref='',$amount='9.99',$freetag='your_f
             else
             {
                 $out.='&securekey='.($mode?'<font color="#666666">':'');
-                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + 'order' + order_ref)";
-                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . 'order' . $ref, 2);
+                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + '".$type."' + order_ref)";
+                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . $type . $ref, 2);
                 $out.=($mode?'</font>':'');
             }
         }
@@ -267,8 +267,8 @@ function getPaypalPaymentUrl($mode,$type,$ref='',$amount='9.99',$freetag='your_f
             else
             {
                 $out.='&securekey='.($mode?'<font color="#666666">':'');
-                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + 'invoice' + invoice_ref)";
-                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . 'invoice' . $ref, 2);
+                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + '".$type."' + invoice_ref)";
+                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . $type . $ref, 2);
                 $out.=($mode?'</font>':'');
             }
         }
@@ -285,8 +285,8 @@ function getPaypalPaymentUrl($mode,$type,$ref='',$amount='9.99',$freetag='your_f
             else
             {
                 $out.='&securekey='.($mode?'<font color="#666666">':'');
-                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + 'contactline' + contractline_ref)";
-                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . 'contractline' . $ref, 2);
+                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + '".$type."' + contractline_ref)";
+                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . $type . $ref, 2);
                 $out.=($mode?'</font>':'');
             }
         }
@@ -303,15 +303,15 @@ function getPaypalPaymentUrl($mode,$type,$ref='',$amount='9.99',$freetag='your_f
             else
             {
                 $out.='&securekey='.($mode?'<font color="#666666">':'');
-                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + 'membersubscription' + member_ref)";
-                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . 'membersubscription' . $ref, 2);
+                if ($mode == 1) $out.="hash('".$conf->global->PAYPAL_SECURITY_TOKEN."' + '".$type."' + member_ref)";
+                if ($mode == 0) $out.= dol_hash($conf->global->PAYPAL_SECURITY_TOKEN . $type . $ref, 2);
                 $out.=($mode?'</font>':'');
             }
         }
     }
 
     // For multicompany
-    //$out.="&entity=".$conf->entity; // This should not be into link. Link contains already a ref of an object that allow to retreive entity
+    $out.="&entity=".$conf->entity; // Check the entity because He may be the same reference in several entities
 
     return $out;
 }
@@ -406,35 +406,54 @@ function print_paypal_redirect($paymentAmount,$currencyCodeType,$paymentType,$re
         $ErrorLongMsg = urldecode($resArray["L_LONGMESSAGE0"]);
         $ErrorSeverityCode = urldecode($resArray["L_SEVERITYCODE0"]);
 
-        echo "SetExpressCheckout API call failed. <br>\n";
-        echo "Detailed Error Message: " . $ErrorLongMsg." <br>\n";
-        echo "Short Error Message: " . $ErrorShortMsg." <br>\n";
-        echo "Error Code: " . $ErrorCode." <br>\n";
-        echo "Error Severity Code: " . $ErrorSeverityCode." <br>\n";
+        echo $langs->trans('SetExpressCheckoutAPICallFailed') . "<br>\n";
+        echo $langs->trans('DetailedErrorMessage') . ": " . $ErrorLongMsg."<br>\n";
+        echo $langs->trans('ShortErrorMessage') . ": " . $ErrorShortMsg."<br>\n";
+        echo $langs->trans('ErrorCode') . ": " . $ErrorCode."<br>\n";
+        echo $langs->trans('ErrorSeverityCode') . ": " . $ErrorSeverityCode."<br>\n";
     }
 
 }
 
-/*
- '-------------------------------------------------------------------------------------------------------------------------------------------
- ' Purpose:     Prepares the parameters for the SetExpressCheckout API Call.
- ' Inputs:
- '      paymentAmount:      Total value of the shopping cart
- '      currencyCodeType:   Currency code value the PayPal API
- '      paymentType:        paymentType has to be one of the following values: Sale or Order or Authorization
- '      returnURL:          the page where buyers return to after they are done with the payment review on PayPal
- '      cancelURL:          the page where buyers return to when they cancel the payment review on PayPal
- '      shipToName:     the Ship to name entered on the merchant's site
- '      shipToStreet:       the Ship to Street entered on the merchant's site
- '      shipToCity:         the Ship to City entered on the merchant's site
- '      shipToState:        the Ship to State entered on the merchant's site
- '      shipToCountryCode:  the Code for Ship to Country entered on the merchant's site
- '      shipToZip:          the Ship to ZipCode entered on the merchant's site
- '      shipToStreet2:      the Ship to Street2 entered on the merchant's site
- '      phoneNum:           the phoneNum  entered on the merchant's site
- '      email:              the buyer email
- '      desc:               Product description
- '--------------------------------------------------------------------------------------------------------------------------------------------
+/**
+ *-------------------------------------------------------------------------------------------------------------------------------------------
+ * Purpose:     Prepares the parameters for the SetExpressCheckout API Call.
+ * Inputs:
+ *      paymentAmount:      Total value of the shopping cart
+ *      currencyCodeType:   Currency code value the PayPal API
+ *      paymentType:        paymentType has to be one of the following values: Sale or Order or Authorization
+ *      returnURL:          the page where buyers return to after they are done with the payment review on PayPal
+ *      cancelURL:          the page where buyers return to when they cancel the payment review on PayPal
+ *      shipToName:     the Ship to name entered on the merchant's site
+ *      shipToStreet:       the Ship to Street entered on the merchant's site
+ *      shipToCity:         the Ship to City entered on the merchant's site
+ *      shipToState:        the Ship to State entered on the merchant's site
+ *      shipToCountryCode:  the Code for Ship to Country entered on the merchant's site
+ *      shipToZip:          the Ship to ZipCode entered on the merchant's site
+ *      shipToStreet2:      the Ship to Street2 entered on the merchant's site
+ *      phoneNum:           the phoneNum  entered on the merchant's site
+ *      email:              the buyer email
+ *      desc:               Product description
+ *
+ * @param 	double 			$paymentAmount		Payment amount
+ * @param 	string 			$currencyCodeType	Currency
+ * @param 	string 			$paymentType		Payment type
+ * @param 	string 			$returnURL			Return Url
+ * @param 	string 			$cancelURL			Cancel Url
+ * @param 	string 			$tag				Tag
+ * @param 	string 			$solutionType		Type
+ * @param 	string 			$landingPage		Landing page
+ * @param	string			$shipToName			Ship to name
+ * @param	string			$shipToStreet		Ship to street
+ * @param	string			$shipToCity			Ship to city
+ * @param	string			$shipToState		Ship to state
+ * @param	string			$shipToCountryCode	Ship to country code
+ * @param	string			$shipToZip			Ship to zip
+ * @param	string			$shipToStreet2		Ship to street2
+ * @param	string			$phoneNum			Phone
+ * @param	string			$email				Email
+ * @param	string			$desc				Description
+ * @return	array								Array
  */
 function callSetExpressCheckout($paymentAmount, $currencyCodeType, $paymentType, $returnURL, $cancelURL, $tag, $solutionType, $landingPage, $shipToName, $shipToStreet, $shipToCity, $shipToState, $shipToCountryCode, $shipToZip, $shipToStreet2, $phoneNum, $email='', $desc='')
 {
@@ -473,6 +492,7 @@ function callSetExpressCheckout($paymentAmount, $currencyCodeType, $paymentType,
 	$_SESSION["Payment_Amount"] = $paymentAmount;
     $_SESSION["currencyCodeType"] = $currencyCodeType;
     $_SESSION["PaymentType"] = $paymentType;
+    $_SESSION['ipaddress'] = $_SERVER['REMOTE_ADDR '];  // Payer ip
 
     //'---------------------------------------------------------------------------------------------------------------
     //' Make the API call to PayPal
@@ -485,7 +505,6 @@ function callSetExpressCheckout($paymentAmount, $currencyCodeType, $paymentType,
     {
         $token = urldecode($resArray["TOKEN"]);
         $_SESSION['TOKEN']=$token;
-        $_SESSION['ipaddress']=$_SERVER['REMOTE_ADDR '];  // Payer ip
     }
 
     return $resArray;
@@ -683,8 +702,8 @@ function hash_call($methodName,$nvpStr)
      exit;*/
     curl_setopt($ch, CURLOPT_URL, $API_Endpoint);
     curl_setopt($ch, CURLOPT_VERBOSE, 1);
-    //curl_setopt($ch, CURLOPT_SSLVERSION, 3); // Force SSLv3
-	curl_setopt($ch, CURLOPT_SSLVERSION, 1); // Force TLSv1
+    // TLSv1 by default or change to TLSv1.2 in module configuration
+    curl_setopt($ch, CURLOPT_SSLVERSION, (empty($conf->global->PAYPAL_SSLVERSION)?1:$conf->global->PAYPAL_SSLVERSION));
 
     //turning off the server and peer verification(TrustManager Concept).
     curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
@@ -798,4 +817,3 @@ function getApiError()
 	return $errors;
 }
 
-?>
