@@ -83,6 +83,7 @@ $server->wsdl->addComplexType(
 
 $contact_fields = array(
 	'id' => array('name'=>'id','type'=>'xsd:string'),
+	'ref_ext' => array('name'=>'ref_ext','type'=>'xsd:string'),
 	'lastname' => array('name'=>'lastname','type'=>'xsd:string'),
 	'firstname' => array('name'=>'firstname','type'=>'xsd:string'),
 	'address' => array('name'=>'address','type'=>'xsd:string'),
@@ -113,8 +114,7 @@ $contact_fields = array(
 	'user_id' => array('name'=>'user_id','type'=>'xsd:string'),
 	'user_login' => array('name'=>'user_login','type'=>'xsd:string'),
 	'civility_id' => array('name'=>'civility_id','type'=>'xsd:string'),
-	'poste' => array('name'=>'poste','type'=>'xsd:string'),
-	'statut' => array('name'=>'statut','type'=>'xsd:string')
+	'poste' => array('name'=>'poste','type'=>'xsd:string')
 	//...
 );
 //Retreive all extrafield for contact
@@ -176,14 +176,14 @@ $styleuse='encoded';   // encoded/literal/literal wrapped
 $server->register(
     'getContact',
     // Entry values
-    array('authentication'=>'tns:authentication','id'=>'xsd:string','ref'=>'xsd:string','ref_ext'=>'xsd:string'),
+    array('authentication'=>'tns:authentication','id'=>'xsd:string','ref_ext'=>'xsd:string'),
     // Exit values
     array('result'=>'tns:result','contact'=>'tns:contact'),
     $ns,
     $ns.'#getContact',
     $styledoc,
     $styleuse,
-    'WS to get contact'
+    'WS to get a contact'
 );
 
 // Register WSDL
@@ -233,15 +233,14 @@ $server->register(
  *
  * @param	array		$authentication		Array of authentication information
  * @param	int			$id					Id of object
- * @param	string		$ref				Ref of object
- * @param	ref_ext		$ref_ext			Ref external of object
+ * @param	string		$ref_ext			Ref external of object
  * @return	mixed
  */
-function getContact($authentication,$id,$ref='',$ref_ext='')
+function getContact($authentication,$id,$ref_ext)
 {
     global $db,$conf,$langs;
 
-    dol_syslog("Function: getContact login=".$authentication['login']." id=".$id." ref=".$ref." ref_ext=".$ref_ext);
+    dol_syslog("Function: getContact login=".$authentication['login']." id=".$id." ref_ext=".$ref_ext);
 
     if ($authentication['entity']) $conf->entity=$authentication['entity'];
 
@@ -251,10 +250,10 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
     $error=0;
     $fuser=check_authentication($authentication,$error,$errorcode,$errorlabel);
     // Check parameters
-    if (! $error && (($id && $ref) || ($id && $ref_ext) || ($ref && $ref_ext)))
+    if (! $error && ($id && $ref_ext))
     {
         $error++;
-        $errorcode='BAD_PARAMETERS'; $errorlabel="Parameter id, ref and ref_ext can't be both provided. You must choose one or other but not both.";
+        $errorcode='BAD_PARAMETERS'; $errorlabel="Parameter id and ref_ext can't be both provided. You must choose one or other but not both.";
     }
 
     if (! $error)
@@ -262,7 +261,7 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
         $fuser->getrights();
 
         $contact=new Contact($db);
-        $result=$contact->fetch($id,$ref,$ref_ext);
+        $result=$contact->fetch($id,0,$ref_ext);
         if ($result > 0)
         {
         	// Only internal user who have contact read permission
@@ -273,6 +272,7 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
 	        ){
             	$contact_result_fields =array(
 	            	'id' => $contact->id,
+	            	'ref_ext' => $contact->ref_ext,
 	            	'lastname' => $contact->lastname,
 	            	'firstname' => $contact->firstname,
 	            	'address' => $contact->address,
@@ -285,7 +285,7 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
 	            	'country_code' => $contact->country_code,
 	            	'country' => $contact->country,
 	            	'socid' => $contact->socid,
-	            	'status' => $contact->status,
+	            	'status' => $contact->statut,
 	            	'phone_pro' => $contact->phone_pro,
 	            	'fax' => $contact->fax,
 	            	'phone_perso' => $contact->phone_perso,
@@ -302,24 +302,23 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
 	            	'ref_propal' => $contact->ref_propal,
 	            	'user_id' => $contact->user_id,
 	            	'user_login' => $contact->user_login,
-	            	'civilite_id' => $contact->civility_id,
-            		'poste' => $contact->poste,
-            		'statut' => $contact->statut
+	            	'civility_id' => $contact->civility_id,
+            		'poste' => $contact->poste
             	);
-            	
+
             	//Retreive all extrafield for thirdsparty
             	// fetch optionals attributes and labels
             	$extrafields=new ExtraFields($db);
             	$extralabels=$extrafields->fetch_name_optionals_label('socpeople',true);
             	//Get extrafield values
             	$contact->fetch_optionals($contact->id,$extralabels);
-            	
+
             	foreach($extrafields->attribute_label as $key=>$label)
             	{
             		$contact_result_fields=array_merge($contact_result_fields,array('options_'.$key => $contact->array_options['options_'.$key]));
             	}
-            	
-            	
+
+
                 // Create
                 $objectresp = array(
 			    	'result'=>array('result_code'=>'OK', 'result_label'=>''),
@@ -335,7 +334,7 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
          else
          {
              $error++;
-             $errorcode='NOT_FOUND'; $errorlabel='Object not found for id='.$id.' nor ref='.$ref.' nor ref_ext='.$ref_ext;
+             $errorcode='NOT_FOUND'; $errorlabel='Object not found for id='.$id.' nor ref_ext='.$ref_ext;
          }
     }
 
@@ -352,7 +351,7 @@ function getContact($authentication,$id,$ref='',$ref_ext='')
  * Create Contact
  *
  * @param	array		$authentication		Array of authentication information
- * @param	Contact	$contact		    $contact
+ * @param	Contact		$contact		    $contact
  * @return	array							Array result
  */
 function createContact($authentication,$contact)
@@ -378,12 +377,13 @@ function createContact($authentication,$contact)
 
 	if (! $error)
 	{
-		
+
 
 		$newobject=new Contact($db);
-		
+
 		$newobject->id=$contact['id'];
-		$newobject->civilite_id=$contact['civility_id'];
+		$newobject->ref_ext=$contact['ref_ext'];
+		$newobject->civility_id=$contact['civility_id'];
 		$newobject->lastname=$contact['lastname'];
 		$newobject->firstname=$contact['firstname'];
 		$newobject->address=$contact['address'];
@@ -396,7 +396,7 @@ function createContact($authentication,$contact)
 		$newobject->country_code=$contact['country_code'];
 		$newobject->country=$contact['country'];
 		$newobject->socid=$contact['socid'];
-		$newobject->status=$contact['status'];
+		$newobject->statut=$contact['status'];
 		$newobject->phone_pro=$contact['phone_pro'];
 		$newobject->fax=$contact['fax'];
 		$newobject->phone_perso=$contact['phone_perso'];
@@ -414,8 +414,7 @@ function createContact($authentication,$contact)
 		$newobject->user_id=$contact['user_id'];
 		$newobject->user_login=$contact['user_login'];
 		$newobject->poste=$contact['poste'];
-		$newobject->statut=$contact['statut'];
-		
+
 		//Retreive all extrafield for thirdsparty
 		// fetch optionals attributes and labels
 		$extrafields=new ExtraFields($db);
@@ -425,9 +424,9 @@ function createContact($authentication,$contact)
 			$key='options_'.$key;
 			$newobject->array_options[$key]=$contact[$key];
 		}
-		
 
-		
+
+
 		//...
 
 		$db->begin();
@@ -491,24 +490,23 @@ function getContactsForThirdParty($authentication,$idthirdparty)
 	{
 		$linesinvoice=array();
 
-		$sql = "SELECT c.rowid, c.fk_soc, c.civilite as civility_id, c.lastname, c.firstname, c.statut,";
+		$sql = "SELECT c.rowid, c.fk_soc, c.civility as civility_id, c.lastname, c.firstname, c.statut as status,";
 		$sql.= " c.address, c.zip, c.town,";
 		$sql.= " c.fk_pays as country_id,";
 		$sql.= " c.fk_departement,";
 		$sql.= " c.birthday,";
 		$sql.= " c.poste, c.phone, c.phone_perso, c.phone_mobile, c.fax, c.email, c.jabberid,";
 		//$sql.= " c.priv, c.note, c.default_lang, c.no_email, c.canvas,";
-		$sql.= " p.libelle as country, p.code as country_code,";
+		$sql.= " co.label as country, co.code as country_code,";
 		$sql.= " d.nom as state, d.code_departement as state_code,";
 		$sql.= " u.rowid as user_id, u.login as user_login,";
 		$sql.= " s.nom as socname, s.address as socaddress, s.zip as soccp, s.town as soccity, s.default_lang as socdefault_lang";
 		$sql.= " FROM ".MAIN_DB_PREFIX."socpeople as c";
-		$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_pays as p ON c.fk_pays = p.rowid";
+		$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_country as co ON c.fk_pays = co.rowid";
 		$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_departements as d ON c.fk_departement = d.rowid";
 		$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."user as u ON c.rowid = u.fk_socpeople";
 		$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."societe as s ON c.fk_soc = s.rowid";
 		$sql.= " WHERE c.fk_soc=$idthirdparty";
-		
 
 		$resql=$db->query($sql);
 		if ($resql)
@@ -523,58 +521,50 @@ function getContactsForThirdParty($authentication,$idthirdparty)
 				$contact=new Contact($db);
 				$contact->fetch($obj->rowid);
 
-
 				// Now define invoice
 				$linescontact[]=array(
-				'id' => $contact->id,
-				'ref' => $contact->ref,
-				'civility_id' => $contact->civilite_id?$contact->civilite_id:'',  
-				'lastname' => $contact->lastname?$contact->lastname:'',
-				'firstname' => $contact->firstname?$contact->firstname:'',
-				'address' => $contact->address?$contact->address:'',
-				'zip' => $contact->zip?$contact->zip:'',
-				'town' => $contact->town?$contact->town:'',
-				
-				'state_id' => $contact->state_id?$contact->state_id:'',
-				'state_code' => $contact->state_code?$contact->state_code:'',
-				'state' => $contact->state?$contact->state:'',
-				
-				'country_id' => $contact->country_id?$contact->country_id:'',
-				'country_code' => $contact->country_code?$contact->country_code:'',
-				'country' => $contact->country?$contact->country:'',
-				
-				'socid' => $contact->socid?$contact->socid:'',
-				'socname' => $contact->socname?$contact->socname:'',
-				'poste' => $contact->poste?$contact->poste:'',
-				
-				
-				
-				'phone_pro' => $contact->phone_pro?$contact->phone_pro:'',
-				'fax' => $contact->fax?$contact->fax:'',
-				'phone_perso' => $contact->phone_perso?$contact->phone_perso:'',
-				'phone_mobile' => $contact->phone_mobile?$contact->phone_mobile:'',
-				
-				'email' => $contact->email?$contact->email:'',
-				'jabberid' => $contact->jabberid?$contact->jabberid:'',
-				'priv' => $contact->priv?$contact->priv:'',
-				'mail' => $contact->mail?$contact->mail:'',
-				
-				'birthday' => $contact->birthday?$contact->birthday:'',
-				'default_lang' => $contact->default_lang?$contact->default_lang:'',
-				'note' => $contact->note?$contact->note:'',
-				'no_email' => $contact->no_email?$contact->no_email:'',
-				'ref_facturation' => $contact->ref_facturation?$contact->ref_facturation:'',
-				'ref_contrat' => $contact->ref_contrat?$contact->ref_contrat:'',
-				'ref_commande' => $contact->ref_commande?$contact->ref_commande:'',
-				'ref_propal' => $contact->ref_propal?$contact->ref_propal:'',
-				'user_id' => $contact->user_id?$contact->user_id:'',
-				'user_login' => $contact->user_login?$contact->user_login:'',
-				'statut' => $contact->statut?$contact->statut:''
-				
-				
-				
-				
-				
+					'id' => $contact->id,
+					'ref' => $contact->ref,
+					'civility_id' => $contact->civility_id?$contact->civility_id:'',
+					'lastname' => $contact->lastname?$contact->lastname:'',
+					'firstname' => $contact->firstname?$contact->firstname:'',
+					'address' => $contact->address?$contact->address:'',
+					'zip' => $contact->zip?$contact->zip:'',
+					'town' => $contact->town?$contact->town:'',
+
+					'state_id' => $contact->state_id?$contact->state_id:'',
+					'state_code' => $contact->state_code?$contact->state_code:'',
+					'state' => $contact->state?$contact->state:'',
+
+					'country_id' => $contact->country_id?$contact->country_id:'',
+					'country_code' => $contact->country_code?$contact->country_code:'',
+					'country' => $contact->country?$contact->country:'',
+
+					'socid' => $contact->socid?$contact->socid:'',
+					'socname' => $contact->socname?$contact->socname:'',
+					'poste' => $contact->poste?$contact->poste:'',
+
+					'phone_pro' => $contact->phone_pro?$contact->phone_pro:'',
+					'fax' => $contact->fax?$contact->fax:'',
+					'phone_perso' => $contact->phone_perso?$contact->phone_perso:'',
+					'phone_mobile' => $contact->phone_mobile?$contact->phone_mobile:'',
+
+					'email' => $contact->email?$contact->email:'',
+					'jabberid' => $contact->jabberid?$contact->jabberid:'',
+					'priv' => $contact->priv?$contact->priv:'',
+					'mail' => $contact->mail?$contact->mail:'',
+
+					'birthday' => $contact->birthday?$contact->birthday:'',
+					'default_lang' => $contact->default_lang?$contact->default_lang:'',
+					'note' => $contact->note?$contact->note:'',
+					'no_email' => $contact->no_email?$contact->no_email:'',
+					'ref_facturation' => $contact->ref_facturation?$contact->ref_facturation:'',
+					'ref_contrat' => $contact->ref_contrat?$contact->ref_contrat:'',
+					'ref_commande' => $contact->ref_commande?$contact->ref_commande:'',
+					'ref_propal' => $contact->ref_propal?$contact->ref_propal:'',
+					'user_id' => $contact->user_id?$contact->user_id:'',
+					'user_login' => $contact->user_login?$contact->user_login:'',
+					'status' => $contact->statut?$contact->statut:''
 				);
 
 				$i++;
@@ -625,9 +615,15 @@ function updateContact($authentication,$contact)
 	$error=0;
 	$fuser=check_authentication($authentication,$error,$errorcode,$errorlabel);
 	// Check parameters
-	if (empty($contact['id']))	{
-		$error++; $errorcode='KO'; $errorlabel="Contact id is mandatory.";
+	if (empty($contact['id']) && empty($contact['ref_ext']))	{
+		$error++; $errorcode='KO'; $errorlabel="Contact id or ref_ext is mandatory.";
 	}
+	// Check parameters
+    if (! $error && ($id && $ref_ext))
+    {
+        $error++;
+        $errorcode='BAD_PARAMETERS'; $errorlabel="Parameter id and ref_ext can't be all provided. You must choose one of them.";
+    }
 
 	if (! $error)
 	{
@@ -636,16 +632,16 @@ function updateContact($authentication,$contact)
 		include_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';
 
 		$object=new Contact($db);
-		$result=$object->fetch($contact['id']);
+		$result=$object->fetch($contact['id'],0,$contact['ref_ext']);
 
 		if (!empty($object->id)) {
 
 			$objectfound=true;
-				
-			
+
+
 			$object->firstname=$contact['firstname'];
 			$object->lastname=$contact['lastname'];
-			
+
 			$object->address=$contact['address'];
 			$object->zip=$contact['zip'];
 			$object->town=$contact['town'];
@@ -653,19 +649,19 @@ function updateContact($authentication,$contact)
 			$object->country_id=$contact['country_id'];
 			if ($contact['country_code']) $object->country_id=getCountry($contact['country_code'],3);
 			$object->province_id=$contact['province_id'];
-		
+
 
 			$object->phone_pro=$contact['phone_pro'];
 			$object->phone_perso=$contact['phone_perso'];
 			$object->phone_mobile=$contact['phone_mobile'];
 			$object->fax=$contact['fax'];
 			$object->email=$contact['email'];
-			
-			$object->civilite_id=$contact['civility_id'];
+
+			$object->civility_id=$contact['civility_id'];
 			$object->poste=$contact['poste'];
-			
-			$object->statut=$contact['statut'];
-			
+
+			$object->statut=$contact['status'];
+
 
 			//Retreive all extrafield for contact
 			// fetch optionals attributes and labels
@@ -713,7 +709,6 @@ function updateContact($authentication,$contact)
 
 	return $objectresp;
 }
-// Return the results.
-$server->service($HTTP_RAW_POST_DATA);
 
-?>
+// Return the results.
+$server->service(file_get_contents("php://input"));
